<?php

declare(strict_types=1);

namespace BladeComponents\Undraw\Providers;

use BladeComponents\Undraw\Components\UndrawComponent;
use Illuminate\Support\Facades\Blade;
use Illuminate\Support\ServiceProvider;

final class UndrawServiceProvider extends ServiceProvider
{
    public function boot(): void
    {
        $this->loadViewsFrom(__DIR__ . '/../../resources/views', 'undraw');

        if ($this->app->runningInConsole()) {
            $this->publishes([
                __DIR__ . '/../../resources/views' => resource_path('views/vendor/undraw'),
            ], 'views');
        }

        Blade::component(UndrawComponent::class, 'undraw');

        Blade::components([
            \BladeComponents\Undraw\Components\Illustrations\Undraw3dModelingComponent::class => '3d-modeling',
            \BladeComponents\Undraw\Components\Illustrations\UndrawABetterWorldComponent::class => 'a-better-world',
            \BladeComponents\Undraw\Components\Illustrations\UndrawADayAtTheParkComponent::class => 'a-day-at-the-park',
            \BladeComponents\Undraw\Components\Illustrations\UndrawADayOffComponent::class => 'a-day-off',
            \BladeComponents\Undraw\Components\Illustrations\UndrawAMomentToRelaxComponent::class => 'a-moment-to-relax',
            \BladeComponents\Undraw\Components\Illustrations\UndrawAWholeYearComponent::class => 'a-whole-year',
            \BladeComponents\Undraw\Components\Illustrations\UndrawAboutMeComponent::class => 'about-me',
            \BladeComponents\Undraw\Components\Illustrations\UndrawAboutUsPageComponent::class => 'about-us-page',
            \BladeComponents\Undraw\Components\Illustrations\UndrawAbsorbedInComponent::class => 'absorbed-in',
            \BladeComponents\Undraw\Components\Illustrations\UndrawAbstractComponent::class => 'abstract',
            \BladeComponents\Undraw\Components\Illustrations\UndrawAcceptRequestComponent::class => 'accept-request',
            \BladeComponents\Undraw\Components\Illustrations\UndrawAcceptTasksComponent::class => 'accept-tasks',
            \BladeComponents\Undraw\Components\Illustrations\UndrawAccessAccountComponent::class => 'access-account',
            \BladeComponents\Undraw\Components\Illustrations\UndrawAccessDeniedComponent::class => 'access-denied',
            \BladeComponents\Undraw\Components\Illustrations\UndrawAccountComponent::class => 'account',
            \BladeComponents\Undraw\Components\Illustrations\UndrawActiveOptionsComponent::class => 'active-options',
            \BladeComponents\Undraw\Components\Illustrations\UndrawActiveSupportComponent::class => 'active-support',
            \BladeComponents\Undraw\Components\Illustrations\UndrawActivityTrackerComponent::class => 'activity-tracker',
            \BladeComponents\Undraw\Components\Illustrations\UndrawAddColorComponent::class => 'add-color',
            \BladeComponents\Undraw\Components\Illustrations\UndrawAddContentComponent::class => 'add-content',
            \BladeComponents\Undraw\Components\Illustrations\UndrawAddDocumentComponent::class => 'add-document',
            \BladeComponents\Undraw\Components\Illustrations\UndrawAddFileComponent::class => 'add-file',
            \BladeComponents\Undraw\Components\Illustrations\UndrawAddFilesComponent::class => 'add-files',
            \BladeComponents\Undraw\Components\Illustrations\UndrawAddFriendsComponent::class => 'add-friends',
            \BladeComponents\Undraw\Components\Illustrations\UndrawAddInformationComponent::class => 'add-information',
            \BladeComponents\Undraw\Components\Illustrations\UndrawAddNotesComponent::class => 'add-notes',
            \BladeComponents\Undraw\Components\Illustrations\UndrawAddPostComponent::class => 'add-post',
            \BladeComponents\Undraw\Components\Illustrations\UndrawAddTasksComponent::class => 'add-tasks',
            \BladeComponents\Undraw\Components\Illustrations\UndrawAddToCartComponent::class => 'add-to-cart',
            \BladeComponents\Undraw\Components\Illustrations\UndrawAddUserComponent::class => 'add-user',
            \BladeComponents\Undraw\Components\Illustrations\UndrawAddressComponent::class => 'address',
            \BladeComponents\Undraw\Components\Illustrations\UndrawAdjustmentsComponent::class => 'adjustments',
            \BladeComponents\Undraw\Components\Illustrations\UndrawAdvancedCustomizationComponent::class => 'advanced-customization',
            \BladeComponents\Undraw\Components\Illustrations\UndrawAdventureComponent::class => 'adventure',
            \BladeComponents\Undraw\Components\Illustrations\UndrawAdventureMapComponent::class => 'adventure-map',
            \BladeComponents\Undraw\Components\Illustrations\UndrawAgreeComponent::class => 'agree',
            \BladeComponents\Undraw\Components\Illustrations\UndrawAgreementComponent::class => 'agreement',
            \BladeComponents\Undraw\Components\Illustrations\UndrawAirSupportComponent::class => 'air-support',
            \BladeComponents\Undraw\Components\Illustrations\UndrawAircraftComponent::class => 'aircraft',
            \BladeComponents\Undraw\Components\Illustrations\UndrawAlertComponent::class => 'alert',
            \BladeComponents\Undraw\Components\Illustrations\UndrawAlgoliaComponent::class => 'algolia',
            \BladeComponents\Undraw\Components\Illustrations\UndrawAlienScienceComponent::class => 'alien-science',
            \BladeComponents\Undraw\Components\Illustrations\UndrawAllTheDataComponent::class => 'all-the-data',
            \BladeComponents\Undraw\Components\Illustrations\UndrawAmongNatureComponent::class => 'among-nature',
            \BladeComponents\Undraw\Components\Illustrations\UndrawAmusementParkComponent::class => 'amusement-park',
            \BladeComponents\Undraw\Components\Illustrations\UndrawAnalysisComponent::class => 'analysis',
            \BladeComponents\Undraw\Components\Illustrations\UndrawAnalyticsComponent::class => 'analytics',
            \BladeComponents\Undraw\Components\Illustrations\UndrawAnalyzeComponent::class => 'analyze',
            \BladeComponents\Undraw\Components\Illustrations\UndrawAndroidComponent::class => 'android',
            \BladeComponents\Undraw\Components\Illustrations\UndrawAnimatingComponent::class => 'animating',
            \BladeComponents\Undraw\Components\Illustrations\UndrawAnnotationComponent::class => 'annotation',
            \BladeComponents\Undraw\Components\Illustrations\UndrawAnonymousFeedbackComponent::class => 'anonymous-feedback',
            \BladeComponents\Undraw\Components\Illustrations\UndrawApartmentRentComponent::class => 'apartment-rent',
            \BladeComponents\Undraw\Components\Illustrations\UndrawAppDataComponent::class => 'app-data',
            \BladeComponents\Undraw\Components\Illustrations\UndrawAppInstallationComponent::class => 'app-installation',
            \BladeComponents\Undraw\Components\Illustrations\UndrawAppWireframeComponent::class => 'app-wireframe',
            \BladeComponents\Undraw\Components\Illustrations\UndrawAppreciateItComponent::class => 'appreciate-it',
            \BladeComponents\Undraw\Components\Illustrations\UndrawAppreciationComponent::class => 'appreciation',
            \BladeComponents\Undraw\Components\Illustrations\UndrawApproveComponent::class => 'approve',
            \BladeComponents\Undraw\Components\Illustrations\UndrawAppsComponent::class => 'apps',
            \BladeComponents\Undraw\Components\Illustrations\UndrawAroundTheWorldComponent::class => 'around-the-world',
            \BladeComponents\Undraw\Components\Illustrations\UndrawArrivedComponent::class => 'arrived',
            \BladeComponents\Undraw\Components\Illustrations\UndrawArtComponent::class => 'art',
            \BladeComponents\Undraw\Components\Illustrations\UndrawArtLoverComponent::class => 'art-lover',
            \BladeComponents\Undraw\Components\Illustrations\UndrawArtMuseumComponent::class => 'art-museum',
            \BladeComponents\Undraw\Components\Illustrations\UndrawArtThinkingComponent::class => 'art-thinking',
            \BladeComponents\Undraw\Components\Illustrations\UndrawArticlesComponent::class => 'articles',
            \BladeComponents\Undraw\Components\Illustrations\UndrawArtificialIntelligenceComponent::class => 'artificial-intelligence',
            \BladeComponents\Undraw\Components\Illustrations\UndrawArtistComponent::class => 'artist',
            \BladeComponents\Undraw\Components\Illustrations\UndrawAskMeAnythingComponent::class => 'ask-me-anything',
            \BladeComponents\Undraw\Components\Illustrations\UndrawAssetSelectionComponent::class => 'asset-selection',
            \BladeComponents\Undraw\Components\Illustrations\UndrawAstronautComponent::class => 'astronaut',
            \BladeComponents\Undraw\Components\Illustrations\UndrawAtHomeComponent::class => 'at-home',
            \BladeComponents\Undraw\Components\Illustrations\UndrawAtTheParkComponent::class => 'at-the-park',
            \BladeComponents\Undraw\Components\Illustrations\UndrawAtWorkComponent::class => 'at-work',
            \BladeComponents\Undraw\Components\Illustrations\UndrawAttachedFileComponent::class => 'attached-file',
            \BladeComponents\Undraw\Components\Illustrations\UndrawAudioConversationComponent::class => 'audio-conversation',
            \BladeComponents\Undraw\Components\Illustrations\UndrawAudioPlayerComponent::class => 'audio-player',
            \BladeComponents\Undraw\Components\Illustrations\UndrawAugmentedRealityComponent::class => 'augmented-reality',
            \BladeComponents\Undraw\Components\Illustrations\UndrawAuthenticationComponent::class => 'authentication',
            \BladeComponents\Undraw\Components\Illustrations\UndrawAutumnComponent::class => 'autumn',
            \BladeComponents\Undraw\Components\Illustrations\UndrawAwardsComponent::class => 'awards',
            \BladeComponents\Undraw\Components\Illustrations\UndrawAwesomeComponent::class => 'awesome',
            \BladeComponents\Undraw\Components\Illustrations\UndrawBabyComponent::class => 'baby',
            \BladeComponents\Undraw\Components\Illustrations\UndrawBackHomeComponent::class => 'back-home',
            \BladeComponents\Undraw\Components\Illustrations\UndrawBalloonsComponent::class => 'balloons',
            \BladeComponents\Undraw\Components\Illustrations\UndrawBarbecueComponent::class => 'barbecue',
            \BladeComponents\Undraw\Components\Illustrations\UndrawBarberComponent::class => 'barber',
            \BladeComponents\Undraw\Components\Illustrations\UndrawBaristaComponent::class => 'barista',
            \BladeComponents\Undraw\Components\Illustrations\UndrawBasketballComponent::class => 'basketball',
            \BladeComponents\Undraw\Components\Illustrations\UndrawBeTheHeroComponent::class => 'be-the-hero',
            \BladeComponents\Undraw\Components\Illustrations\UndrawBeachDayComponent::class => 'beach-day',
            \BladeComponents\Undraw\Components\Illustrations\UndrawBearMarketComponent::class => 'bear-market',
            \BladeComponents\Undraw\Components\Illustrations\UndrawBeerCelebrationComponent::class => 'beer-celebration',
            \BladeComponents\Undraw\Components\Illustrations\UndrawBeerComponent::class => 'beer',
            \BladeComponents\Undraw\Components\Illustrations\UndrawBeforeDawnComponent::class => 'before-dawn',
            \BladeComponents\Undraw\Components\Illustrations\UndrawBeginChatComponent::class => 'begin-chat',
            \BladeComponents\Undraw\Components\Illustrations\UndrawBestPlaceComponent::class => 'best-place',
            \BladeComponents\Undraw\Components\Illustrations\UndrawBibliophileComponent::class => 'bibliophile',
            \BladeComponents\Undraw\Components\Illustrations\UndrawBikeRideComponent::class => 'bike-ride',
            \BladeComponents\Undraw\Components\Illustrations\UndrawBikingComponent::class => 'biking',
            \BladeComponents\Undraw\Components\Illustrations\UndrawBirthdayCakeComponent::class => 'birthday-cake',
            \BladeComponents\Undraw\Components\Illustrations\UndrawBirthdayGirlComponent::class => 'birthday-girl',
            \BladeComponents\Undraw\Components\Illustrations\UndrawBitcoinComponent::class => 'bitcoin',
            \BladeComponents\Undraw\Components\Illustrations\UndrawBitcoinP2PComponent::class => 'bitcoin-p2p',
            \BladeComponents\Undraw\Components\Illustrations\UndrawBlankCanvasComponent::class => 'blank-canvas',
            \BladeComponents\Undraw\Components\Illustrations\UndrawBlogPostComponent::class => 'blog-post',
            \BladeComponents\Undraw\Components\Illustrations\UndrawBloggingComponent::class => 'blogging',
            \BladeComponents\Undraw\Components\Illustrations\UndrawBloomingComponent::class => 'blooming',
            \BladeComponents\Undraw\Components\Illustrations\UndrawBodyTextComponent::class => 'body-text',
            \BladeComponents\Undraw\Components\Illustrations\UndrawBookLoverComponent::class => 'book-lover',
            \BladeComponents\Undraw\Components\Illustrations\UndrawBookReadingComponent::class => 'book-reading',
            \BladeComponents\Undraw\Components\Illustrations\UndrawBookedComponent::class => 'booked',
            \BladeComponents\Undraw\Components\Illustrations\UndrawBookingComponent::class => 'booking',
            \BladeComponents\Undraw\Components\Illustrations\UndrawBookmarksComponent::class => 'bookmarks',
            \BladeComponents\Undraw\Components\Illustrations\UndrawBooksComponent::class => 'books',
            \BladeComponents\Undraw\Components\Illustrations\UndrawBookshelvesComponent::class => 'bookshelves',
            \BladeComponents\Undraw\Components\Illustrations\UndrawBothSidesComponent::class => 'both-sides',
            \BladeComponents\Undraw\Components\Illustrations\UndrawBrainstormingComponent::class => 'brainstorming',
            \BladeComponents\Undraw\Components\Illustrations\UndrawBreakfastComponent::class => 'breakfast',
            \BladeComponents\Undraw\Components\Illustrations\UndrawBreakingBarriersComponent::class => 'breaking-barriers',
            \BladeComponents\Undraw\Components\Illustrations\UndrawBroadcastComponent::class => 'broadcast',
            \BladeComponents\Undraw\Components\Illustrations\UndrawBrowserStatsComponent::class => 'browser-stats',
            \BladeComponents\Undraw\Components\Illustrations\UndrawBrowsingComponent::class => 'browsing',
            \BladeComponents\Undraw\Components\Illustrations\UndrawBrowsingOnlineComponent::class => 'browsing-online',
            \BladeComponents\Undraw\Components\Illustrations\UndrawBuddiesComponent::class => 'buddies',
            \BladeComponents\Undraw\Components\Illustrations\UndrawBufferComponent::class => 'buffer',
            \BladeComponents\Undraw\Components\Illustrations\UndrawBugFixingComponent::class => 'bug-fixing',
            \BladeComponents\Undraw\Components\Illustrations\UndrawBuildWireframeComponent::class => 'build-wireframe',
            \BladeComponents\Undraw\Components\Illustrations\UndrawBuildYourHomeComponent::class => 'build-your-home',
            \BladeComponents\Undraw\Components\Illustrations\UndrawBuildingBlocksComponent::class => 'building-blocks',
            \BladeComponents\Undraw\Components\Illustrations\UndrawBuildingComponent::class => 'building',
            \BladeComponents\Undraw\Components\Illustrations\UndrawBuildingWebsitesComponent::class => 'building-websites',
            \BladeComponents\Undraw\Components\Illustrations\UndrawBusStopComponent::class => 'bus-stop',
            \BladeComponents\Undraw\Components\Illustrations\UndrawBusinessAnalyticsComponent::class => 'business-analytics',
            \BladeComponents\Undraw\Components\Illustrations\UndrawBusinessChatComponent::class => 'business-chat',
            \BladeComponents\Undraw\Components\Illustrations\UndrawBusinessDealComponent::class => 'business-deal',
            \BladeComponents\Undraw\Components\Illustrations\UndrawBusinessDecisionsComponent::class => 'business-decisions',
            \BladeComponents\Undraw\Components\Illustrations\UndrawBusinessManComponent::class => 'business-man',
            \BladeComponents\Undraw\Components\Illustrations\UndrawBusinessPlanComponent::class => 'business-plan',
            \BladeComponents\Undraw\Components\Illustrations\UndrawBusinessShopComponent::class => 'business-shop',
            \BladeComponents\Undraw\Components\Illustrations\UndrawBusinessmanComponent::class => 'businessman',
            \BladeComponents\Undraw\Components\Illustrations\UndrawBusinesswomanComponent::class => 'businesswoman',
            \BladeComponents\Undraw\Components\Illustrations\UndrawButtonStyleComponent::class => 'button-style',
            \BladeComponents\Undraw\Components\Illustrations\UndrawBuyHouseComponent::class => 'buy-house',
            \BladeComponents\Undraw\Components\Illustrations\UndrawByTheRoadComponent::class => 'by-the-road',
            \BladeComponents\Undraw\Components\Illustrations\UndrawCMSComponent::class => 'cms',
            \BladeComponents\Undraw\Components\Illustrations\UndrawCabinComponent::class => 'cabin',
            \BladeComponents\Undraw\Components\Illustrations\UndrawCalculatorComponent::class => 'calculator',
            \BladeComponents\Undraw\Components\Illustrations\UndrawCalendarComponent::class => 'calendar',
            \BladeComponents\Undraw\Components\Illustrations\UndrawCallingComponent::class => 'calling',
            \BladeComponents\Undraw\Components\Illustrations\UndrawCameraComponent::class => 'camera',
            \BladeComponents\Undraw\Components\Illustrations\UndrawCampfireComponent::class => 'campfire',
            \BladeComponents\Undraw\Components\Illustrations\UndrawCampingComponent::class => 'camping',
            \BladeComponents\Undraw\Components\Illustrations\UndrawCancelComponent::class => 'cancel',
            \BladeComponents\Undraw\Components\Illustrations\UndrawCandidateComponent::class => 'candidate',
            \BladeComponents\Undraw\Components\Illustrations\UndrawCarRepairComponent::class => 'car-repair',
            \BladeComponents\Undraw\Components\Illustrations\UndrawCardPostalComponent::class => 'card-postal',
            \BladeComponents\Undraw\Components\Illustrations\UndrawCareerDevelopmentComponent::class => 'career-development',
            \BladeComponents\Undraw\Components\Illustrations\UndrawCareerProgressComponent::class => 'career-progress',
            \BladeComponents\Undraw\Components\Illustrations\UndrawCatComponent::class => 'cat',
            \BladeComponents\Undraw\Components\Illustrations\UndrawCelebratingComponent::class => 'celebrating',
            \BladeComponents\Undraw\Components\Illustrations\UndrawCelebrationComponent::class => 'celebration',
            \BladeComponents\Undraw\Components\Illustrations\UndrawCertificateComponent::class => 'certificate',
            \BladeComponents\Undraw\Components\Illustrations\UndrawCertificationComponent::class => 'certification',
            \BladeComponents\Undraw\Components\Illustrations\UndrawCharacterDrawingComponent::class => 'character-drawing',
            \BladeComponents\Undraw\Components\Illustrations\UndrawChartsComponent::class => 'charts',
            \BladeComponents\Undraw\Components\Illustrations\UndrawChasingLoveComponent::class => 'chasing-love',
            \BladeComponents\Undraw\Components\Illustrations\UndrawChatBotComponent::class => 'chat-bot',
            \BladeComponents\Undraw\Components\Illustrations\UndrawChatComponent::class => 'chat',
            \BladeComponents\Undraw\Components\Illustrations\UndrawChattingComponent::class => 'chatting',
            \BladeComponents\Undraw\Components\Illustrations\UndrawCheckBoxesComponent::class => 'check-boxes',
            \BladeComponents\Undraw\Components\Illustrations\UndrawCheckingBoxesComponent::class => 'checking-boxes',
            \BladeComponents\Undraw\Components\Illustrations\UndrawChecklistComponent::class => 'checklist',
            \BladeComponents\Undraw\Components\Illustrations\UndrawChefComponent::class => 'chef',
            \BladeComponents\Undraw\Components\Illustrations\UndrawChildrenComponent::class => 'children',
            \BladeComponents\Undraw\Components\Illustrations\UndrawChillingComponent::class => 'chilling',
            \BladeComponents\Undraw\Components\Illustrations\UndrawChoiceComponent::class => 'choice',
            \BladeComponents\Undraw\Components\Illustrations\UndrawChooseComponent::class => 'choose',
            \BladeComponents\Undraw\Components\Illustrations\UndrawChoosingHouseComponent::class => 'choosing-house',
            \BladeComponents\Undraw\Components\Illustrations\UndrawChoreListComponent::class => 'chore-list',
            \BladeComponents\Undraw\Components\Illustrations\UndrawChristmasModeComponent::class => 'christmas-mode',
            \BladeComponents\Undraw\Components\Illustrations\UndrawChristmasStockingComponent::class => 'christmas-stocking',
            \BladeComponents\Undraw\Components\Illustrations\UndrawCirclesComponent::class => 'circles',
            \BladeComponents\Undraw\Components\Illustrations\UndrawCircuitBoardComponent::class => 'circuit-board',
            \BladeComponents\Undraw\Components\Illustrations\UndrawCircuitComponent::class => 'circuit',
            \BladeComponents\Undraw\Components\Illustrations\UndrawCityDriverComponent::class => 'city-driver',
            \BladeComponents\Undraw\Components\Illustrations\UndrawCityGirlComponent::class => 'city-girl',
            \BladeComponents\Undraw\Components\Illustrations\UndrawCityLifeComponent::class => 'city-life',
            \BladeComponents\Undraw\Components\Illustrations\UndrawCleanUpComponent::class => 'clean-up',
            \BladeComponents\Undraw\Components\Illustrations\UndrawClickHereComponent::class => 'click-here',
            \BladeComponents\Undraw\Components\Illustrations\UndrawCloseTabComponent::class => 'close-tab',
            \BladeComponents\Undraw\Components\Illustrations\UndrawCloudDocsComponent::class => 'cloud-docs',
            \BladeComponents\Undraw\Components\Illustrations\UndrawCloudFilesComponent::class => 'cloud-files',
            \BladeComponents\Undraw\Components\Illustrations\UndrawCloudHostingComponent::class => 'cloud-hosting',
            \BladeComponents\Undraw\Components\Illustrations\UndrawCloudSyncComponent::class => 'cloud-sync',
            \BladeComponents\Undraw\Components\Illustrations\UndrawCoWorkersComponent::class => 'co-workers',
            \BladeComponents\Undraw\Components\Illustrations\UndrawCoWorkingComponent::class => 'co-working',
            \BladeComponents\Undraw\Components\Illustrations\UndrawCodeInspectionComponent::class => 'code-inspection',
            \BladeComponents\Undraw\Components\Illustrations\UndrawCodeReviewComponent::class => 'code-review',
            \BladeComponents\Undraw\Components\Illustrations\UndrawCodeThinkingComponent::class => 'code-thinking',
            \BladeComponents\Undraw\Components\Illustrations\UndrawCodeTypingComponent::class => 'code-typing',
            \BladeComponents\Undraw\Components\Illustrations\UndrawCodingComponent::class => 'coding',
            \BladeComponents\Undraw\Components\Illustrations\UndrawCoffeeBreakComponent::class => 'coffee-break',
            \BladeComponents\Undraw\Components\Illustrations\UndrawCoffeeComponent::class => 'coffee',
            \BladeComponents\Undraw\Components\Illustrations\UndrawCoffeeTimeComponent::class => 'coffee-time',
            \BladeComponents\Undraw\Components\Illustrations\UndrawCoffeeWithFriendsComponent::class => 'coffee-with-friends',
            \BladeComponents\Undraw\Components\Illustrations\UndrawCohortAnalysisComponent::class => 'cohort-analysis',
            \BladeComponents\Undraw\Components\Illustrations\UndrawCollabComponent::class => 'collab',
            \BladeComponents\Undraw\Components\Illustrations\UndrawCollaboratingComponent::class => 'collaborating',
            \BladeComponents\Undraw\Components\Illustrations\UndrawCollaborationComponent::class => 'collaboration',
            \BladeComponents\Undraw\Components\Illustrations\UndrawCollaboratorsComponent::class => 'collaborators',
            \BladeComponents\Undraw\Components\Illustrations\UndrawCollectingComponent::class => 'collecting',
            \BladeComponents\Undraw\Components\Illustrations\UndrawCollectionComponent::class => 'collection',
            \BladeComponents\Undraw\Components\Illustrations\UndrawColorPaletteComponent::class => 'color-palette',
            \BladeComponents\Undraw\Components\Illustrations\UndrawColorSchemesComponent::class => 'color-schemes',
            \BladeComponents\Undraw\Components\Illustrations\UndrawComingHomeComponent::class => 'coming-home',
            \BladeComponents\Undraw\Components\Illustrations\UndrawCommunityComponent::class => 'community',
            \BladeComponents\Undraw\Components\Illustrations\UndrawCompleteDesignComponent::class => 'complete-design',
            \BladeComponents\Undraw\Components\Illustrations\UndrawCompleteTaskComponent::class => 'complete-task',
            \BladeComponents\Undraw\Components\Illustrations\UndrawCompletedComponent::class => 'completed',
            \BladeComponents\Undraw\Components\Illustrations\UndrawCompletedStepsComponent::class => 'completed-steps',
            \BladeComponents\Undraw\Components\Illustrations\UndrawCompletedTasksComponent::class => 'completed-tasks',
            \BladeComponents\Undraw\Components\Illustrations\UndrawCompletingComponent::class => 'completing',
            \BladeComponents\Undraw\Components\Illustrations\UndrawComposeMusicComponent::class => 'compose-music',
            \BladeComponents\Undraw\Components\Illustrations\UndrawCompositionComponent::class => 'composition',
            \BladeComponents\Undraw\Components\Illustrations\UndrawConceptualIdeaComponent::class => 'conceptual-idea',
            \BladeComponents\Undraw\Components\Illustrations\UndrawConferenceCallComponent::class => 'conference-call',
            \BladeComponents\Undraw\Components\Illustrations\UndrawConferenceComponent::class => 'conference',
            \BladeComponents\Undraw\Components\Illustrations\UndrawConferenceSpeakerComponent::class => 'conference-speaker',
            \BladeComponents\Undraw\Components\Illustrations\UndrawConfidentialLetterComponent::class => 'confidential-letter',
            \BladeComponents\Undraw\Components\Illustrations\UndrawConfirmComponent::class => 'confirm',
            \BladeComponents\Undraw\Components\Illustrations\UndrawConfirmationComponent::class => 'confirmation',
            \BladeComponents\Undraw\Components\Illustrations\UndrawConfirmedComponent::class => 'confirmed',
            \BladeComponents\Undraw\Components\Illustrations\UndrawConnectedComponent::class => 'connected',
            \BladeComponents\Undraw\Components\Illustrations\UndrawConnectedWorldComponent::class => 'connected-world',
            \BladeComponents\Undraw\Components\Illustrations\UndrawConnectingTeamsComponent::class => 'connecting-teams',
            \BladeComponents\Undraw\Components\Illustrations\UndrawConnectionComponent::class => 'connection',
            \BladeComponents\Undraw\Components\Illustrations\UndrawContactUsComponent::class => 'contact-us',
            \BladeComponents\Undraw\Components\Illustrations\UndrawContainerShipComponent::class => 'container-ship',
            \BladeComponents\Undraw\Components\Illustrations\UndrawContemplatingComponent::class => 'contemplating',
            \BladeComponents\Undraw\Components\Illustrations\UndrawContentComponent::class => 'content',
            \BladeComponents\Undraw\Components\Illustrations\UndrawContentCreatorComponent::class => 'content-creator',
            \BladeComponents\Undraw\Components\Illustrations\UndrawContentStructureComponent::class => 'content-structure',
            \BladeComponents\Undraw\Components\Illustrations\UndrawContentTeamComponent::class => 'content-team',
            \BladeComponents\Undraw\Components\Illustrations\UndrawContractComponent::class => 'contract',
            \BladeComponents\Undraw\Components\Illustrations\UndrawContrastComponent::class => 'contrast',
            \BladeComponents\Undraw\Components\Illustrations\UndrawControlPanelComponent::class => 'control-panel',
            \BladeComponents\Undraw\Components\Illustrations\UndrawConversationComponent::class => 'conversation',
            \BladeComponents\Undraw\Components\Illustrations\UndrawConvertComponent::class => 'convert',
            \BladeComponents\Undraw\Components\Illustrations\UndrawCookieLoveComponent::class => 'cookie-love',
            \BladeComponents\Undraw\Components\Illustrations\UndrawCookingComponent::class => 'cooking',
            \BladeComponents\Undraw\Components\Illustrations\UndrawCoolnessComponent::class => 'coolness',
            \BladeComponents\Undraw\Components\Illustrations\UndrawCountingStarsComponent::class => 'counting-stars',
            \BladeComponents\Undraw\Components\Illustrations\UndrawCountrySideComponent::class => 'country-side',
            \BladeComponents\Undraw\Components\Illustrations\UndrawCoupleComponent::class => 'couple',
            \BladeComponents\Undraw\Components\Illustrations\UndrawCoupleLoveComponent::class => 'couple-love',
            \BladeComponents\Undraw\Components\Illustrations\UndrawCreateComponent::class => 'create',
            \BladeComponents\Undraw\Components\Illustrations\UndrawCreationComponent::class => 'creation',
            \BladeComponents\Undraw\Components\Illustrations\UndrawCreationProcessComponent::class => 'creation-process',
            \BladeComponents\Undraw\Components\Illustrations\UndrawCreativeDraftComponent::class => 'creative-draft',
            \BladeComponents\Undraw\Components\Illustrations\UndrawCreativeExperimentComponent::class => 'creative-experiment',
            \BladeComponents\Undraw\Components\Illustrations\UndrawCreativeProcessComponent::class => 'creative-process',
            \BladeComponents\Undraw\Components\Illustrations\UndrawCreativeTeamComponent::class => 'creative-team',
            \BladeComponents\Undraw\Components\Illustrations\UndrawCreativeThinkingComponent::class => 'creative-thinking',
            \BladeComponents\Undraw\Components\Illustrations\UndrawCreativeWomanComponent::class => 'creative-woman',
            \BladeComponents\Undraw\Components\Illustrations\UndrawCreativityComponent::class => 'creativity',
            \BladeComponents\Undraw\Components\Illustrations\UndrawCreditCardComponent::class => 'credit-card',
            \BladeComponents\Undraw\Components\Illustrations\UndrawCreditCardPaymentComponent::class => 'credit-card-payment',
            \BladeComponents\Undraw\Components\Illustrations\UndrawCreditCardPaymentsComponent::class => 'credit-card-payments',
            \BladeComponents\Undraw\Components\Illustrations\UndrawCryptoFlowersComponent::class => 'crypto-flowers',
            \BladeComponents\Undraw\Components\Illustrations\UndrawCryptoPortfolioComponent::class => 'crypto-portfolio',
            \BladeComponents\Undraw\Components\Illustrations\UndrawCurrentLocationComponent::class => 'current-location',
            \BladeComponents\Undraw\Components\Illustrations\UndrawCustomerSurveyComponent::class => 'customer-survey',
            \BladeComponents\Undraw\Components\Illustrations\UndrawDarkAlleyComponent::class => 'dark-alley',
            \BladeComponents\Undraw\Components\Illustrations\UndrawDarkAnalyticsComponent::class => 'dark-analytics',
            \BladeComponents\Undraw\Components\Illustrations\UndrawDarkModeComponent::class => 'dark-mode',
            \BladeComponents\Undraw\Components\Illustrations\UndrawDashboardComponent::class => 'dashboard',
            \BladeComponents\Undraw\Components\Illustrations\UndrawDataComponent::class => 'data',
            \BladeComponents\Undraw\Components\Illustrations\UndrawDataExtractionComponent::class => 'data-extraction',
            \BladeComponents\Undraw\Components\Illustrations\UndrawDataInputComponent::class => 'data-input',
            \BladeComponents\Undraw\Components\Illustrations\UndrawDataPointsComponent::class => 'data-points',
            \BladeComponents\Undraw\Components\Illustrations\UndrawDataProcessingComponent::class => 'data-processing',
            \BladeComponents\Undraw\Components\Illustrations\UndrawDataReportComponent::class => 'data-report',
            \BladeComponents\Undraw\Components\Illustrations\UndrawDataReportsComponent::class => 'data-reports',
            \BladeComponents\Undraw\Components\Illustrations\UndrawDataTrendsComponent::class => 'data-trends',
            \BladeComponents\Undraw\Components\Illustrations\UndrawDateNightComponent::class => 'date-night',
            \BladeComponents\Undraw\Components\Illustrations\UndrawDatePickerComponent::class => 'date-picker',
            \BladeComponents\Undraw\Components\Illustrations\UndrawDecideComponent::class => 'decide',
            \BladeComponents\Undraw\Components\Illustrations\UndrawDeconstructedComponent::class => 'deconstructed',
            \BladeComponents\Undraw\Components\Illustrations\UndrawDecorateChristmasTreeComponent::class => 'decorate-christmas-tree',
            \BladeComponents\Undraw\Components\Illustrations\UndrawDeliveriesComponent::class => 'deliveries',
            \BladeComponents\Undraw\Components\Illustrations\UndrawDeliveryAddressComponent::class => 'delivery-address',
            \BladeComponents\Undraw\Components\Illustrations\UndrawDeliveryComponent::class => 'delivery',
            \BladeComponents\Undraw\Components\Illustrations\UndrawDeliveryTruckComponent::class => 'delivery-truck',
            \BladeComponents\Undraw\Components\Illustrations\UndrawDepartingComponent::class => 'departing',
            \BladeComponents\Undraw\Components\Illustrations\UndrawDesignCommunityComponent::class => 'design-community',
            \BladeComponents\Undraw\Components\Illustrations\UndrawDesignComponentsComponent::class => 'design-components',
            \BladeComponents\Undraw\Components\Illustrations\UndrawDesignDataComponent::class => 'design-data',
            \BladeComponents\Undraw\Components\Illustrations\UndrawDesignFeedbackComponent::class => 'design-feedback',
            \BladeComponents\Undraw\Components\Illustrations\UndrawDesignInspirationComponent::class => 'design-inspiration',
            \BladeComponents\Undraw\Components\Illustrations\UndrawDesignNotesComponent::class => 'design-notes',
            \BladeComponents\Undraw\Components\Illustrations\UndrawDesignObjectivesComponent::class => 'design-objectives',
            \BladeComponents\Undraw\Components\Illustrations\UndrawDesignProcessComponent::class => 'design-process',
            \BladeComponents\Undraw\Components\Illustrations\UndrawDesignSprintComponent::class => 'design-sprint',
            \BladeComponents\Undraw\Components\Illustrations\UndrawDesignStatsComponent::class => 'design-stats',
            \BladeComponents\Undraw\Components\Illustrations\UndrawDesignTeamComponent::class => 'design-team',
            \BladeComponents\Undraw\Components\Illustrations\UndrawDesignThinkingComponent::class => 'design-thinking',
            \BladeComponents\Undraw\Components\Illustrations\UndrawDesignToolsComponent::class => 'design-tools',
            \BladeComponents\Undraw\Components\Illustrations\UndrawDesignerComponent::class => 'designer',
            \BladeComponents\Undraw\Components\Illustrations\UndrawDesignerGirlComponent::class => 'designer-girl',
            \BladeComponents\Undraw\Components\Illustrations\UndrawDesignerLifeComponent::class => 'designer-life',
            \BladeComponents\Undraw\Components\Illustrations\UndrawDesignerMindsetComponent::class => 'designer-mindset',
            \BladeComponents\Undraw\Components\Illustrations\UndrawDestinationComponent::class => 'destination',
            \BladeComponents\Undraw\Components\Illustrations\UndrawDestinationsComponent::class => 'destinations',
            \BladeComponents\Undraw\Components\Illustrations\UndrawDetailedAnalysisComponent::class => 'detailed-analysis',
            \BladeComponents\Undraw\Components\Illustrations\UndrawDetailedExaminationComponent::class => 'detailed-examination',
            \BladeComponents\Undraw\Components\Illustrations\UndrawDetailedInformationComponent::class => 'detailed-information',
            \BladeComponents\Undraw\Components\Illustrations\UndrawDetailsComponent::class => 'details',
            \BladeComponents\Undraw\Components\Illustrations\UndrawDevFocusComponent::class => 'dev-focus',
            \BladeComponents\Undraw\Components\Illustrations\UndrawDevProductivityComponent::class => 'dev-productivity',
            \BladeComponents\Undraw\Components\Illustrations\UndrawDevelopAppComponent::class => 'develop-app',
            \BladeComponents\Undraw\Components\Illustrations\UndrawDeveloperActivityComponent::class => 'developer-activity',
            \BladeComponents\Undraw\Components\Illustrations\UndrawDevelopmentComponent::class => 'development',
            \BladeComponents\Undraw\Components\Illustrations\UndrawDevicesComponent::class => 'devices',
            \BladeComponents\Undraw\Components\Illustrations\UndrawDiaryComponent::class => 'diary',
            \BladeComponents\Undraw\Components\Illustrations\UndrawDietComponent::class => 'diet',
            \BladeComponents\Undraw\Components\Illustrations\UndrawDifferentLoveComponent::class => 'different-love',
            \BladeComponents\Undraw\Components\Illustrations\UndrawDigitalCurrencyComponent::class => 'digital-currency',
            \BladeComponents\Undraw\Components\Illustrations\UndrawDigitalNomadComponent::class => 'digital-nomad',
            \BladeComponents\Undraw\Components\Illustrations\UndrawDirectionsComponent::class => 'directions',
            \BladeComponents\Undraw\Components\Illustrations\UndrawDiscountComponent::class => 'discount',
            \BladeComponents\Undraw\Components\Illustrations\UndrawDiscoverableComponent::class => 'discoverable',
            \BladeComponents\Undraw\Components\Illustrations\UndrawDoctorComponent::class => 'doctor',
            \BladeComponents\Undraw\Components\Illustrations\UndrawDoctorsComponent::class => 'doctors',
            \BladeComponents\Undraw\Components\Illustrations\UndrawDocumentsComponent::class => 'documents',
            \BladeComponents\Undraw\Components\Illustrations\UndrawDogComponent::class => 'dog',
            \BladeComponents\Undraw\Components\Illustrations\UndrawDogWalkingComponent::class => 'dog-walking',
            \BladeComponents\Undraw\Components\Illustrations\UndrawDollPlayComponent::class => 'doll-play',
            \BladeComponents\Undraw\Components\Illustrations\UndrawDomainNamesComponent::class => 'domain-names',
            \BladeComponents\Undraw\Components\Illustrations\UndrawDoneCheckingComponent::class => 'done-checking',
            \BladeComponents\Undraw\Components\Illustrations\UndrawDoneComponent::class => 'done',
            \BladeComponents\Undraw\Components\Illustrations\UndrawDonutLoveComponent::class => 'donut-love',
            \BladeComponents\Undraw\Components\Illustrations\UndrawDownloadComponent::class => 'download',
            \BladeComponents\Undraw\Components\Illustrations\UndrawDragComponent::class => 'drag',
            \BladeComponents\Undraw\Components\Illustrations\UndrawDreamWorldComponent::class => 'dream-world',
            \BladeComponents\Undraw\Components\Illustrations\UndrawDreamerComponent::class => 'dreamer',
            \BladeComponents\Undraw\Components\Illustrations\UndrawDrinkCoffeeComponent::class => 'drink-coffee',
            \BladeComponents\Undraw\Components\Illustrations\UndrawDroneDeliveryComponent::class => 'drone-delivery',
            \BladeComponents\Undraw\Components\Illustrations\UndrawDroneRaceComponent::class => 'drone-race',
            \BladeComponents\Undraw\Components\Illustrations\UndrawDroneSurveillanceComponent::class => 'drone-surveillance',
            \BladeComponents\Undraw\Components\Illustrations\UndrawDropdownMenuComponent::class => 'dropdown-menu',
            \BladeComponents\Undraw\Components\Illustrations\UndrawDuaLipaComponent::class => 'dua-lipa',
            \BladeComponents\Undraw\Components\Illustrations\UndrawDuplicateComponent::class => 'duplicate',
            \BladeComponents\Undraw\Components\Illustrations\UndrawEatingTogetherComponent::class => 'eating-together',
            \BladeComponents\Undraw\Components\Illustrations\UndrawEcoConsciousComponent::class => 'eco-conscious',
            \BladeComponents\Undraw\Components\Illustrations\UndrawEditPhotoComponent::class => 'edit-photo',
            \BladeComponents\Undraw\Components\Illustrations\UndrawEditableComponent::class => 'editable',
            \BladeComponents\Undraw\Components\Illustrations\UndrawEducationComponent::class => 'education',
            \BladeComponents\Undraw\Components\Illustrations\UndrawEducatorComponent::class => 'educator',
            \BladeComponents\Undraw\Components\Illustrations\UndrawEiffelTowerComponent::class => 'eiffel-tower',
            \BladeComponents\Undraw\Components\Illustrations\UndrawElectionDayComponent::class => 'election-day',
            \BladeComponents\Undraw\Components\Illustrations\UndrawElectricCarComponent::class => 'electric-car',
            \BladeComponents\Undraw\Components\Illustrations\UndrawElectricityComponent::class => 'electricity',
            \BladeComponents\Undraw\Components\Illustrations\UndrawElementsComponent::class => 'elements',
            \BladeComponents\Undraw\Components\Illustrations\UndrawEmailCampaignComponent::class => 'email-campaign',
            \BladeComponents\Undraw\Components\Illustrations\UndrawEmailCaptureComponent::class => 'email-capture',
            \BladeComponents\Undraw\Components\Illustrations\UndrawEmailsComponent::class => 'emails',
            \BladeComponents\Undraw\Components\Illustrations\UndrawEmptyCartComponent::class => 'empty-cart',
            \BladeComponents\Undraw\Components\Illustrations\UndrawEmptyComponent::class => 'empty',
            \BladeComponents\Undraw\Components\Illustrations\UndrawEmptyStreetComponent::class => 'empty-street',
            \BladeComponents\Undraw\Components\Illustrations\UndrawEnergizerComponent::class => 'energizer',
            \BladeComponents\Undraw\Components\Illustrations\UndrawEngineeringTeamComponent::class => 'engineering-team',
            \BladeComponents\Undraw\Components\Illustrations\UndrawEnterComponent::class => 'enter',
            \BladeComponents\Undraw\Components\Illustrations\UndrawEnvelopeComponent::class => 'envelope',
            \BladeComponents\Undraw\Components\Illustrations\UndrawEnvironmentComponent::class => 'environment',
            \BladeComponents\Undraw\Components\Illustrations\UndrawEnvironmentalStudyComponent::class => 'environmental-study',
            \BladeComponents\Undraw\Components\Illustrations\UndrawEscapingComponent::class => 'escaping',
            \BladeComponents\Undraw\Components\Illustrations\UndrawEtherComponent::class => 'ether',
            \BladeComponents\Undraw\Components\Illustrations\UndrawEthereumComponent::class => 'ethereum',
            \BladeComponents\Undraw\Components\Illustrations\UndrawEventsComponent::class => 'events',
            \BladeComponents\Undraw\Components\Illustrations\UndrawEverydayDesignComponent::class => 'everyday-design',
            \BladeComponents\Undraw\Components\Illustrations\UndrawEverydayLifeComponent::class => 'everyday-life',
            \BladeComponents\Undraw\Components\Illustrations\UndrawEverywhereTogetherComponent::class => 'everywhere-together',
            \BladeComponents\Undraw\Components\Illustrations\UndrawExamsComponent::class => 'exams',
            \BladeComponents\Undraw\Components\Illustrations\UndrawExcitingNewsComponent::class => 'exciting-news',
            \BladeComponents\Undraw\Components\Illustrations\UndrawExpectingComponent::class => 'expecting',
            \BladeComponents\Undraw\Components\Illustrations\UndrawExperienceDesignComponent::class => 'experience-design',
            \BladeComponents\Undraw\Components\Illustrations\UndrawExpertsComponent::class => 'experts',
            \BladeComponents\Undraw\Components\Illustrations\UndrawExploreComponent::class => 'explore',
            \BladeComponents\Undraw\Components\Illustrations\UndrawExploringComponent::class => 'exploring',
            \BladeComponents\Undraw\Components\Illustrations\UndrawExportFilesComponent::class => 'export-files',
            \BladeComponents\Undraw\Components\Illustrations\UndrawFactoryComponent::class => 'factory',
            \BladeComponents\Undraw\Components\Illustrations\UndrawFallComponent::class => 'fall',
            \BladeComponents\Undraw\Components\Illustrations\UndrawFallIsComingComponent::class => 'fall-is-coming',
            \BladeComponents\Undraw\Components\Illustrations\UndrawFamilyComponent::class => 'family',
            \BladeComponents\Undraw\Components\Illustrations\UndrawFansComponent::class => 'fans',
            \BladeComponents\Undraw\Components\Illustrations\UndrawFaqComponent::class => 'faq',
            \BladeComponents\Undraw\Components\Illustrations\UndrawFarmGirlComponent::class => 'farm-girl',
            \BladeComponents\Undraw\Components\Illustrations\UndrawFashionBloggingComponent::class => 'fashion-blogging',
            \BladeComponents\Undraw\Components\Illustrations\UndrawFashionPhotoshootComponent::class => 'fashion-photoshoot',
            \BladeComponents\Undraw\Components\Illustrations\UndrawFastComponent::class => 'fast',
            \BladeComponents\Undraw\Components\Illustrations\UndrawFastLoadingComponent::class => 'fast-loading',
            \BladeComponents\Undraw\Components\Illustrations\UndrawFatherhoodComponent::class => 'fatherhood',
            \BladeComponents\Undraw\Components\Illustrations\UndrawFeaturesOverviewComponent::class => 'features-overview',
            \BladeComponents\Undraw\Components\Illustrations\UndrawFeedbackComponent::class => 'feedback',
            \BladeComponents\Undraw\Components\Illustrations\UndrawFeelingBlueComponent::class => 'feeling-blue',
            \BladeComponents\Undraw\Components\Illustrations\UndrawFeelingHappyComponent::class => 'feeling-happy',
            \BladeComponents\Undraw\Components\Illustrations\UndrawFeelingOfJoyComponent::class => 'feeling-of-joy',
            \BladeComponents\Undraw\Components\Illustrations\UndrawFeelingProudComponent::class => 'feeling-proud',
            \BladeComponents\Undraw\Components\Illustrations\UndrawFemaleAvatarComponent::class => 'female-avatar',
            \BladeComponents\Undraw\Components\Illustrations\UndrawFestivitiesComponent::class => 'festivities',
            \BladeComponents\Undraw\Components\Illustrations\UndrawFileAnalysisComponent::class => 'file-analysis',
            \BladeComponents\Undraw\Components\Illustrations\UndrawFileBundleComponent::class => 'file-bundle',
            \BladeComponents\Undraw\Components\Illustrations\UndrawFileManagerComponent::class => 'file-manager',
            \BladeComponents\Undraw\Components\Illustrations\UndrawFileSearchingComponent::class => 'file-searching',
            \BladeComponents\Undraw\Components\Illustrations\UndrawFileSyncComponent::class => 'file-sync',
            \BladeComponents\Undraw\Components\Illustrations\UndrawFileSynchronizationComponent::class => 'file-synchronization',
            \BladeComponents\Undraw\Components\Illustrations\UndrawFilesSentComponent::class => 'files-sent',
            \BladeComponents\Undraw\Components\Illustrations\UndrawFilingSystemComponent::class => 'filing-system',
            \BladeComponents\Undraw\Components\Illustrations\UndrawFillFormsComponent::class => 'fill-forms',
            \BladeComponents\Undraw\Components\Illustrations\UndrawFillInComponent::class => 'fill-in',
            \BladeComponents\Undraw\Components\Illustrations\UndrawFilterComponent::class => 'filter',
            \BladeComponents\Undraw\Components\Illustrations\UndrawFinanceComponent::class => 'finance',
            \BladeComponents\Undraw\Components\Illustrations\UndrawFinancialDataComponent::class => 'financial-data',
            \BladeComponents\Undraw\Components\Illustrations\UndrawFingerprintComponent::class => 'fingerprint',
            \BladeComponents\Undraw\Components\Illustrations\UndrawFingerprintLoginComponent::class => 'fingerprint-login',
            \BladeComponents\Undraw\Components\Illustrations\UndrawFinishLineComponent::class => 'finish-line',
            \BladeComponents\Undraw\Components\Illustrations\UndrawFireworksComponent::class => 'fireworks',
            \BladeComponents\Undraw\Components\Illustrations\UndrawFirmwareComponent::class => 'firmware',
            \BladeComponents\Undraw\Components\Illustrations\UndrawFishBowlComponent::class => 'fish-bowl',
            \BladeComponents\Undraw\Components\Illustrations\UndrawFishingComponent::class => 'fishing',
            \BladeComponents\Undraw\Components\Illustrations\UndrawFitnessStatsComponent::class => 'fitness-stats',
            \BladeComponents\Undraw\Components\Illustrations\UndrawFitnessTrackerComponent::class => 'fitness-tracker',
            \BladeComponents\Undraw\Components\Illustrations\UndrawFittingPieceComponent::class => 'fitting-piece',
            \BladeComponents\Undraw\Components\Illustrations\UndrawFittingPiecesComponent::class => 'fitting-pieces',
            \BladeComponents\Undraw\Components\Illustrations\UndrawFixingBugsComponent::class => 'fixing-bugs',
            \BladeComponents\Undraw\Components\Illustrations\UndrawFlaggedComponent::class => 'flagged',
            \BladeComponents\Undraw\Components\Illustrations\UndrawFloatingComponent::class => 'floating',
            \BladeComponents\Undraw\Components\Illustrations\UndrawFlowersComponent::class => 'flowers',
            \BladeComponents\Undraw\Components\Illustrations\UndrawFlutterDevComponent::class => 'flutter-dev',
            \BladeComponents\Undraw\Components\Illustrations\UndrawFlyingDroneComponent::class => 'flying-drone',
            \BladeComponents\Undraw\Components\Illustrations\UndrawFocusComponent::class => 'focus',
            \BladeComponents\Undraw\Components\Illustrations\UndrawFolderComponent::class => 'folder',
            \BladeComponents\Undraw\Components\Illustrations\UndrawFolderFilesComponent::class => 'folder-files',
            \BladeComponents\Undraw\Components\Illustrations\UndrawFollowMeDroneComponent::class => 'follow-me-drone',
            \BladeComponents\Undraw\Components\Illustrations\UndrawFollowersComponent::class => 'followers',
            \BladeComponents\Undraw\Components\Illustrations\UndrawFollowingComponent::class => 'following',
            \BladeComponents\Undraw\Components\Illustrations\UndrawFontComponent::class => 'font',
            \BladeComponents\Undraw\Components\Illustrations\UndrawForReviewComponent::class => 'for-review',
            \BladeComponents\Undraw\Components\Illustrations\UndrawForSaleComponent::class => 'for-sale',
            \BladeComponents\Undraw\Components\Illustrations\UndrawForgotPasswordComponent::class => 'forgot-password',
            \BladeComponents\Undraw\Components\Illustrations\UndrawFormingIdeasComponent::class => 'forming-ideas',
            \BladeComponents\Undraw\Components\Illustrations\UndrawFormsComponent::class => 'forms',
            \BladeComponents\Undraw\Components\Illustrations\UndrawFreelancerComponent::class => 'freelancer',
            \BladeComponents\Undraw\Components\Illustrations\UndrawFreshNotificationComponent::class => 'fresh-notification',
            \BladeComponents\Undraw\Components\Illustrations\UndrawFriendsComponent::class => 'friends',
            \BladeComponents\Undraw\Components\Illustrations\UndrawFriendsOnlineComponent::class => 'friends-online',
            \BladeComponents\Undraw\Components\Illustrations\UndrawFriendshipComponent::class => 'friendship',
            \BladeComponents\Undraw\Components\Illustrations\UndrawFrozenFigureComponent::class => 'frozen-figure',
            \BladeComponents\Undraw\Components\Illustrations\UndrawFunMomentsComponent::class => 'fun-moments',
            \BladeComponents\Undraw\Components\Illustrations\UndrawFunctionsComponent::class => 'functions',
            \BladeComponents\Undraw\Components\Illustrations\UndrawFuturisticInterfaceComponent::class => 'futuristic-interface',
            \BladeComponents\Undraw\Components\Illustrations\UndrawGDPRComponent::class => 'gdpr',
            \BladeComponents\Undraw\Components\Illustrations\UndrawGameDayComponent::class => 'game-day',
            \BladeComponents\Undraw\Components\Illustrations\UndrawGameWorldComponent::class => 'game-world',
            \BladeComponents\Undraw\Components\Illustrations\UndrawGamingComponent::class => 'gaming',
            \BladeComponents\Undraw\Components\Illustrations\UndrawGardeningComponent::class => 'gardening',
            \BladeComponents\Undraw\Components\Illustrations\UndrawGatsbyJsComponent::class => 'gatsbyjs',
            \BladeComponents\Undraw\Components\Illustrations\UndrawGeniusComponent::class => 'genius',
            \BladeComponents\Undraw\Components\Illustrations\UndrawGettingCoffeeComponent::class => 'getting-coffee',
            \BladeComponents\Undraw\Components\Illustrations\UndrawGiftBoxComponent::class => 'gift-box',
            \BladeComponents\Undraw\Components\Illustrations\UndrawGiftCardComponent::class => 'gift-card',
            \BladeComponents\Undraw\Components\Illustrations\UndrawGiftComponent::class => 'gift',
            \BladeComponents\Undraw\Components\Illustrations\UndrawGiftsComponent::class => 'gifts',
            \BladeComponents\Undraw\Components\Illustrations\UndrawGirlsJustWannaHaveFunComponent::class => 'girls-just-wanna-have-fun',
            \BladeComponents\Undraw\Components\Illustrations\UndrawGoalComponent::class => 'goal',
            \BladeComponents\Undraw\Components\Illustrations\UndrawGoalsComponent::class => 'goals',
            \BladeComponents\Undraw\Components\Illustrations\UndrawGoingOfflineComponent::class => 'going-offline',
            \BladeComponents\Undraw\Components\Illustrations\UndrawGoingUpComponent::class => 'going-up',
            \BladeComponents\Undraw\Components\Illustrations\UndrawGoldenGateBridgeComponent::class => 'golden-gate-bridge',
            \BladeComponents\Undraw\Components\Illustrations\UndrawGolfComponent::class => 'golf',
            \BladeComponents\Undraw\Components\Illustrations\UndrawGoneShoppingComponent::class => 'gone-shopping',
            \BladeComponents\Undraw\Components\Illustrations\UndrawGoodDoggyComponent::class => 'good-doggy',
            \BladeComponents\Undraw\Components\Illustrations\UndrawGoodTeamComponent::class => 'good-team',
            \BladeComponents\Undraw\Components\Illustrations\UndrawGoogleDocsComponent::class => 'google-docs',
            \BladeComponents\Undraw\Components\Illustrations\UndrawGradesComponent::class => 'grades',
            \BladeComponents\Undraw\Components\Illustrations\UndrawGraduationComponent::class => 'graduation',
            \BladeComponents\Undraw\Components\Illustrations\UndrawGrandSlamComponent::class => 'grand-slam',
            \BladeComponents\Undraw\Components\Illustrations\UndrawGrandmaComponent::class => 'grandma',
            \BladeComponents\Undraw\Components\Illustrations\UndrawGravitasComponent::class => 'gravitas',
            \BladeComponents\Undraw\Components\Illustrations\UndrawGreekFreakComponent::class => 'greek-freak',
            \BladeComponents\Undraw\Components\Illustrations\UndrawGridDesignComponent::class => 'grid-design',
            \BladeComponents\Undraw\Components\Illustrations\UndrawGroupChatComponent::class => 'group-chat',
            \BladeComponents\Undraw\Components\Illustrations\UndrawGroupHangoutComponent::class => 'group-hangout',
            \BladeComponents\Undraw\Components\Illustrations\UndrawGroupSelfieComponent::class => 'group-selfie',
            \BladeComponents\Undraw\Components\Illustrations\UndrawGroupVideoComponent::class => 'group-video',
            \BladeComponents\Undraw\Components\Illustrations\UndrawGrowingComponent::class => 'growing',
            \BladeComponents\Undraw\Components\Illustrations\UndrawGrowthAnalyticsComponent::class => 'growth-analytics',
            \BladeComponents\Undraw\Components\Illustrations\UndrawGrowthChartComponent::class => 'growth-chart',
            \BladeComponents\Undraw\Components\Illustrations\UndrawGrowthCurveComponent::class => 'growth-curve',
            \BladeComponents\Undraw\Components\Illustrations\UndrawHackerMindComponent::class => 'hacker-mind',
            \BladeComponents\Undraw\Components\Illustrations\UndrawHackerMindsetComponent::class => 'hacker-mindset',
            \BladeComponents\Undraw\Components\Illustrations\UndrawHalloweenComponent::class => 'halloween',
            \BladeComponents\Undraw\Components\Illustrations\UndrawHamburgerComponent::class => 'hamburger',
            \BladeComponents\Undraw\Components\Illustrations\UndrawHangOutComponent::class => 'hang-out',
            \BladeComponents\Undraw\Components\Illustrations\UndrawHappy2019Component::class => 'happy-2019',
            \BladeComponents\Undraw\Components\Illustrations\UndrawHappy2021Component::class => 'happy-2021',
            \BladeComponents\Undraw\Components\Illustrations\UndrawHappyAnnouncementComponent::class => 'happy-announcement',
            \BladeComponents\Undraw\Components\Illustrations\UndrawHappyBirthdayComponent::class => 'happy-birthday',
            \BladeComponents\Undraw\Components\Illustrations\UndrawHappyFeelingComponent::class => 'happy-feeling',
            \BladeComponents\Undraw\Components\Illustrations\UndrawHappyMusicComponent::class => 'happy-music',
            \BladeComponents\Undraw\Components\Illustrations\UndrawHappyNewYearComponent::class => 'happy-new-year',
            \BladeComponents\Undraw\Components\Illustrations\UndrawHappyNewsComponent::class => 'happy-news',
            \BladeComponents\Undraw\Components\Illustrations\UndrawHappyWomenDayComponent::class => 'happy-women-day',
            \BladeComponents\Undraw\Components\Illustrations\UndrawHavingFunComponent::class => 'having-fun',
            \BladeComponents\Undraw\Components\Illustrations\UndrawHealthyHabitComponent::class => 'healthy-habit',
            \BladeComponents\Undraw\Components\Illustrations\UndrawHealthyLifestyleComponent::class => 'healthy-lifestyle',
            \BladeComponents\Undraw\Components\Illustrations\UndrawHealthyOptionsComponent::class => 'healthy-options',
            \BladeComponents\Undraw\Components\Illustrations\UndrawHeartbrokenComponent::class => 'heartbroken',
            \BladeComponents\Undraw\Components\Illustrations\UndrawHeatmapComponent::class => 'heatmap',
            \BladeComponents\Undraw\Components\Illustrations\UndrawHeavyBoxComponent::class => 'heavy-box',
            \BladeComponents\Undraw\Components\Illustrations\UndrawHelloComponent::class => 'hello',
            \BladeComponents\Undraw\Components\Illustrations\UndrawHelpfulSignComponent::class => 'helpful-sign',
            \BladeComponents\Undraw\Components\Illustrations\UndrawHeyByBasecampComponent::class => 'hey-by-basecamp',
            \BladeComponents\Undraw\Components\Illustrations\UndrawHighFiveComponent::class => 'high-five',
            \BladeComponents\Undraw\Components\Illustrations\UndrawHikingComponent::class => 'hiking',
            \BladeComponents\Undraw\Components\Illustrations\UndrawHireComponent::class => 'hire',
            \BladeComponents\Undraw\Components\Illustrations\UndrawHiringComponent::class => 'hiring',
            \BladeComponents\Undraw\Components\Illustrations\UndrawHologramComponent::class => 'hologram',
            \BladeComponents\Undraw\Components\Illustrations\UndrawHomeCinemaComponent::class => 'home-cinema',
            \BladeComponents\Undraw\Components\Illustrations\UndrawHomeRunComponent::class => 'home-run',
            \BladeComponents\Undraw\Components\Illustrations\UndrawHomeScreenComponent::class => 'home-screen',
            \BladeComponents\Undraw\Components\Illustrations\UndrawHomeSettingsComponent::class => 'home-settings',
            \BladeComponents\Undraw\Components\Illustrations\UndrawHookedComponent::class => 'hooked',
            \BladeComponents\Undraw\Components\Illustrations\UndrawHorrorMovieComponent::class => 'horror-movie',
            \BladeComponents\Undraw\Components\Illustrations\UndrawHotBeverageComponent::class => 'hot-beverage',
            \BladeComponents\Undraw\Components\Illustrations\UndrawHouseSearchingComponent::class => 'house-searching',
            \BladeComponents\Undraw\Components\Illustrations\UndrawHousesComponent::class => 'houses',
            \BladeComponents\Undraw\Components\Illustrations\UndrawICanFlyComponent::class => 'i-can-fly',
            \BladeComponents\Undraw\Components\Illustrations\UndrawIceCreamComponent::class => 'ice-cream',
            \BladeComponents\Undraw\Components\Illustrations\UndrawIconDesignComponent::class => 'icon-design',
            \BladeComponents\Undraw\Components\Illustrations\UndrawIconsComponent::class => 'icons',
            \BladeComponents\Undraw\Components\Illustrations\UndrawIdeasComponent::class => 'ideas',
            \BladeComponents\Undraw\Components\Illustrations\UndrawIdeasFlowComponent::class => 'ideas-flow',
            \BladeComponents\Undraw\Components\Illustrations\UndrawIdeationComponent::class => 'ideation',
            \BladeComponents\Undraw\Components\Illustrations\UndrawImageFocusComponent::class => 'image-focus',
            \BladeComponents\Undraw\Components\Illustrations\UndrawImageFolderComponent::class => 'image-folder',
            \BladeComponents\Undraw\Components\Illustrations\UndrawImageOptionsComponent::class => 'image-options',
            \BladeComponents\Undraw\Components\Illustrations\UndrawImagePostComponent::class => 'image-post',
            \BladeComponents\Undraw\Components\Illustrations\UndrawImageUploadComponent::class => 'image-upload',
            \BladeComponents\Undraw\Components\Illustrations\UndrawImageViewerComponent::class => 'image-viewer',
            \BladeComponents\Undraw\Components\Illustrations\UndrawImagesComponent::class => 'images',
            \BladeComponents\Undraw\Components\Illustrations\UndrawImaginationComponent::class => 'imagination',
            \BladeComponents\Undraw\Components\Illustrations\UndrawInLoveComponent::class => 'in-love',
            \BladeComponents\Undraw\Components\Illustrations\UndrawInNoTimeComponent::class => 'in-no-time',
            \BladeComponents\Undraw\Components\Illustrations\UndrawInProgressComponent::class => 'in-progress',
            \BladeComponents\Undraw\Components\Illustrations\UndrawInRealLifeComponent::class => 'in-real-life',
            \BladeComponents\Undraw\Components\Illustrations\UndrawInSyncComponent::class => 'in-sync',
            \BladeComponents\Undraw\Components\Illustrations\UndrawInTheOfficeComponent::class => 'in-the-office',
            \BladeComponents\Undraw\Components\Illustrations\UndrawInThePoolComponent::class => 'in-the-pool',
            \BladeComponents\Undraw\Components\Illustrations\UndrawInThoughtComponent::class => 'in-thought',
            \BladeComponents\Undraw\Components\Illustrations\UndrawInboxCleanupComponent::class => 'inbox-cleanup',
            \BladeComponents\Undraw\Components\Illustrations\UndrawInboxComponent::class => 'inbox',
            \BladeComponents\Undraw\Components\Illustrations\UndrawIndoorBikeComponent::class => 'indoor-bike',
            \BladeComponents\Undraw\Components\Illustrations\UndrawInfluencerComponent::class => 'influencer',
            \BladeComponents\Undraw\Components\Illustrations\UndrawInformationTabComponent::class => 'information-tab',
            \BladeComponents\Undraw\Components\Illustrations\UndrawInformedDecisionComponent::class => 'informed-decision',
            \BladeComponents\Undraw\Components\Illustrations\UndrawInjuredComponent::class => 'injured',
            \BladeComponents\Undraw\Components\Illustrations\UndrawInnovativeComponent::class => 'innovative',
            \BladeComponents\Undraw\Components\Illustrations\UndrawInsertBlockComponent::class => 'insert-block',
            \BladeComponents\Undraw\Components\Illustrations\UndrawInsertComponent::class => 'insert',
            \BladeComponents\Undraw\Components\Illustrations\UndrawInspectionComponent::class => 'inspection',
            \BladeComponents\Undraw\Components\Illustrations\UndrawInspirationComponent::class => 'inspiration',
            \BladeComponents\Undraw\Components\Illustrations\UndrawInstantAnalysisComponent::class => 'instant-analysis',
            \BladeComponents\Undraw\Components\Illustrations\UndrawInstantInformationComponent::class => 'instant-information',
            \BladeComponents\Undraw\Components\Illustrations\UndrawInstantSupportComponent::class => 'instant-support',
            \BladeComponents\Undraw\Components\Illustrations\UndrawInstructionManualComponent::class => 'instruction-manual',
            \BladeComponents\Undraw\Components\Illustrations\UndrawIntenseFeelingComponent::class => 'intense-feeling',
            \BladeComponents\Undraw\Components\Illustrations\UndrawInteriorDesignComponent::class => 'interior-design',
            \BladeComponents\Undraw\Components\Illustrations\UndrawInternetOnTheGoComponent::class => 'internet-on-the-go',
            \BladeComponents\Undraw\Components\Illustrations\UndrawInterviewComponent::class => 'interview',
            \BladeComponents\Undraw\Components\Illustrations\UndrawIntoTheNightComponent::class => 'into-the-night',
            \BladeComponents\Undraw\Components\Illustrations\UndrawInvestComponent::class => 'invest',
            \BladeComponents\Undraw\Components\Illustrations\UndrawInvestingComponent::class => 'investing',
            \BladeComponents\Undraw\Components\Illustrations\UndrawInvestmentComponent::class => 'investment',
            \BladeComponents\Undraw\Components\Illustrations\UndrawInvestmentDataComponent::class => 'investment-data',
            \BladeComponents\Undraw\Components\Illustrations\UndrawInvestorUpdateComponent::class => 'investor-update',
            \BladeComponents\Undraw\Components\Illustrations\UndrawInviteComponent::class => 'invite',
            \BladeComponents\Undraw\Components\Illustrations\UndrawJapanComponent::class => 'japan',
            \BladeComponents\Undraw\Components\Illustrations\UndrawJavaScriptFrameworksComponent::class => 'javascript-frameworks',
            \BladeComponents\Undraw\Components\Illustrations\UndrawJewelryComponent::class => 'jewelry',
            \BladeComponents\Undraw\Components\Illustrations\UndrawJobHuntComponent::class => 'job-hunt',
            \BladeComponents\Undraw\Components\Illustrations\UndrawJobOffersComponent::class => 'job-offers',
            \BladeComponents\Undraw\Components\Illustrations\UndrawJoggingComponent::class => 'jogging',
            \BladeComponents\Undraw\Components\Illustrations\UndrawJoinComponent::class => 'join',
            \BladeComponents\Undraw\Components\Illustrations\UndrawJourneyComponent::class => 'journey',
            \BladeComponents\Undraw\Components\Illustrations\UndrawJoyrideComponent::class => 'joyride',
            \BladeComponents\Undraw\Components\Illustrations\UndrawJudgeComponent::class => 'judge',
            \BladeComponents\Undraw\Components\Illustrations\UndrawJuniorSoccerComponent::class => 'junior-soccer',
            \BladeComponents\Undraw\Components\Illustrations\UndrawJustBrowsingComponent::class => 'just-browsing',
            \BladeComponents\Undraw\Components\Illustrations\UndrawJustSayingComponent::class => 'just-saying',
            \BladeComponents\Undraw\Components\Illustrations\UndrawKeyPointsComponent::class => 'key-points',
            \BladeComponents\Undraw\Components\Illustrations\UndrawKnowledgeComponent::class => 'knowledge',
            \BladeComponents\Undraw\Components\Illustrations\UndrawLandingPageComponent::class => 'landing-page',
            \BladeComponents\Undraw\Components\Illustrations\UndrawLandscapeModeComponent::class => 'landscape-mode',
            \BladeComponents\Undraw\Components\Illustrations\UndrawLandscapePhotographerComponent::class => 'landscape-photographer',
            \BladeComponents\Undraw\Components\Illustrations\UndrawLaravelAndVueComponent::class => 'laravel-and-vue',
            \BladeComponents\Undraw\Components\Illustrations\UndrawLateAtNightComponent::class => 'late-at-night',
            \BladeComponents\Undraw\Components\Illustrations\UndrawLaunchDayComponent::class => 'launch-day',
            \BladeComponents\Undraw\Components\Illustrations\UndrawLaunchingComponent::class => 'launching',
            \BladeComponents\Undraw\Components\Illustrations\UndrawLearningComponent::class => 'learning',
            \BladeComponents\Undraw\Components\Illustrations\UndrawLearningSketchingComponent::class => 'learning-sketching',
            \BladeComponents\Undraw\Components\Illustrations\UndrawLetterComponent::class => 'letter',
            \BladeComponents\Undraw\Components\Illustrations\UndrawLightTheFireComponent::class => 'light-the-fire',
            \BladeComponents\Undraw\Components\Illustrations\UndrawLightbulbMomentComponent::class => 'lightbulb-moment',
            \BladeComponents\Undraw\Components\Illustrations\UndrawLighthouseComponent::class => 'lighthouse',
            \BladeComponents\Undraw\Components\Illustrations\UndrawLikeDislikeComponent::class => 'like-dislike',
            \BladeComponents\Undraw\Components\Illustrations\UndrawLinkShortenerComponent::class => 'link-shortener',
            \BladeComponents\Undraw\Components\Illustrations\UndrawListeningComponent::class => 'listening',
            \BladeComponents\Undraw\Components\Illustrations\UndrawLiveCollaborationComponent::class => 'live-collaboration',
            \BladeComponents\Undraw\Components\Illustrations\UndrawLivePhotoComponent::class => 'live-photo',
            \BladeComponents\Undraw\Components\Illustrations\UndrawLivingComponent::class => 'living',
            \BladeComponents\Undraw\Components\Illustrations\UndrawLoadMoreComponent::class => 'load-more',
            \BladeComponents\Undraw\Components\Illustrations\UndrawLoadingComponent::class => 'loading',
            \BladeComponents\Undraw\Components\Illustrations\UndrawLocationReviewComponent::class => 'location-review',
            \BladeComponents\Undraw\Components\Illustrations\UndrawLocationSearchComponent::class => 'location-search',
            \BladeComponents\Undraw\Components\Illustrations\UndrawLocationTrackingComponent::class => 'location-tracking',
            \BladeComponents\Undraw\Components\Illustrations\UndrawLogicComponent::class => 'logic',
            \BladeComponents\Undraw\Components\Illustrations\UndrawLoginComponent::class => 'login',
            \BladeComponents\Undraw\Components\Illustrations\UndrawLogisticsComponent::class => 'logistics',
            \BladeComponents\Undraw\Components\Illustrations\UndrawLogoDesignComponent::class => 'logo-design',
            \BladeComponents\Undraw\Components\Illustrations\UndrawLostComponent::class => 'lost',
            \BladeComponents\Undraw\Components\Illustrations\UndrawLoveComponent::class => 'love',
            \BladeComponents\Undraw\Components\Illustrations\UndrawLoveIsInTheAirComponent::class => 'love-is-in-the-air',
            \BladeComponents\Undraw\Components\Illustrations\UndrawLoveItComponent::class => 'love-it',
            \BladeComponents\Undraw\Components\Illustrations\UndrawLovingItComponent::class => 'loving-it',
            \BladeComponents\Undraw\Components\Illustrations\UndrawLovingStoryComponent::class => 'loving-story',
            \BladeComponents\Undraw\Components\Illustrations\UndrawMailComponent::class => 'mail',
            \BladeComponents\Undraw\Components\Illustrations\UndrawMailSentComponent::class => 'mail-sent',
            \BladeComponents\Undraw\Components\Illustrations\UndrawMailboxComponent::class => 'mailbox',
            \BladeComponents\Undraw\Components\Illustrations\UndrawMaintenanceComponent::class => 'maintenance',
            \BladeComponents\Undraw\Components\Illustrations\UndrawMakeItRainComponent::class => 'make-it-rain',
            \BladeComponents\Undraw\Components\Illustrations\UndrawMakerLaunchComponent::class => 'maker-launch',
            \BladeComponents\Undraw\Components\Illustrations\UndrawMakeupArtistComponent::class => 'makeup-artist',
            \BladeComponents\Undraw\Components\Illustrations\UndrawMakingArtComponent::class => 'making-art',
            \BladeComponents\Undraw\Components\Illustrations\UndrawMaleAvatarComponent::class => 'male-avatar',
            \BladeComponents\Undraw\Components\Illustrations\UndrawManageChatsComponent::class => 'manage-chats',
            \BladeComponents\Undraw\Components\Illustrations\UndrawMapComponent::class => 'map',
            \BladeComponents\Undraw\Components\Illustrations\UndrawMapDarkComponent::class => 'map-dark',
            \BladeComponents\Undraw\Components\Illustrations\UndrawMarilynComponent::class => 'marilyn',
            \BladeComponents\Undraw\Components\Illustrations\UndrawMarketingComponent::class => 'marketing',
            \BladeComponents\Undraw\Components\Illustrations\UndrawMasterPlanComponent::class => 'master-plan',
            \BladeComponents\Undraw\Components\Illustrations\UndrawMathematicsComponent::class => 'mathematics',
            \BladeComponents\Undraw\Components\Illustrations\UndrawMediaPlayerComponent::class => 'media-player',
            \BladeComponents\Undraw\Components\Illustrations\UndrawMedicalCareComponent::class => 'medical-care',
            \BladeComponents\Undraw\Components\Illustrations\UndrawMedicalResearchComponent::class => 'medical-research',
            \BladeComponents\Undraw\Components\Illustrations\UndrawMedicineComponent::class => 'medicine',
            \BladeComponents\Undraw\Components\Illustrations\UndrawMeditatingComponent::class => 'meditating',
            \BladeComponents\Undraw\Components\Illustrations\UndrawMeditationComponent::class => 'meditation',
            \BladeComponents\Undraw\Components\Illustrations\UndrawMeetTheTeamComponent::class => 'meet-the-team',
            \BladeComponents\Undraw\Components\Illustrations\UndrawMeetingComponent::class => 'meeting',
            \BladeComponents\Undraw\Components\Illustrations\UndrawMelloComponent::class => 'mello',
            \BladeComponents\Undraw\Components\Illustrations\UndrawMemoryStorageComponent::class => 'memory-storage',
            \BladeComponents\Undraw\Components\Illustrations\UndrawMentionComponent::class => 'mention',
            \BladeComponents\Undraw\Components\Illustrations\UndrawMessageSentComponent::class => 'message-sent',
            \BladeComponents\Undraw\Components\Illustrations\UndrawMessagesComponent::class => 'messages',
            \BladeComponents\Undraw\Components\Illustrations\UndrawMessagingAppComponent::class => 'messaging-app',
            \BladeComponents\Undraw\Components\Illustrations\UndrawMessagingComponent::class => 'messaging',
            \BladeComponents\Undraw\Components\Illustrations\UndrawMessagingFunComponent::class => 'messaging-fun',
            \BladeComponents\Undraw\Components\Illustrations\UndrawMessengerComponent::class => 'messenger',
            \BladeComponents\Undraw\Components\Illustrations\UndrawMetricsComponent::class => 'metrics',
            \BladeComponents\Undraw\Components\Illustrations\UndrawMicDropComponent::class => 'mic-drop',
            \BladeComponents\Undraw\Components\Illustrations\UndrawMillennialGirlComponent::class => 'millennial-girl',
            \BladeComponents\Undraw\Components\Illustrations\UndrawMindMapComponent::class => 'mind-map',
            \BladeComponents\Undraw\Components\Illustrations\UndrawMindfulnessComponent::class => 'mindfulness',
            \BladeComponents\Undraw\Components\Illustrations\UndrawMintTeaComponent::class => 'mint-tea',
            \BladeComponents\Undraw\Components\Illustrations\UndrawMiroComponent::class => 'miro',
            \BladeComponents\Undraw\Components\Illustrations\UndrawMissedChancesComponent::class => 'missed-chances',
            \BladeComponents\Undraw\Components\Illustrations\UndrawMobileAnalyticsComponent::class => 'mobile-analytics',
            \BladeComponents\Undraw\Components\Illustrations\UndrawMobileAppComponent::class => 'mobile-app',
            \BladeComponents\Undraw\Components\Illustrations\UndrawMobileApplicationComponent::class => 'mobile-application',
            \BladeComponents\Undraw\Components\Illustrations\UndrawMobileAppsComponent::class => 'mobile-apps',
            \BladeComponents\Undraw\Components\Illustrations\UndrawMobileBrowsersComponent::class => 'mobile-browsers',
            \BladeComponents\Undraw\Components\Illustrations\UndrawMobileComponent::class => 'mobile',
            \BladeComponents\Undraw\Components\Illustrations\UndrawMobileDevelopmentComponent::class => 'mobile-development',
            \BladeComponents\Undraw\Components\Illustrations\UndrawMobileDevicesComponent::class => 'mobile-devices',
            \BladeComponents\Undraw\Components\Illustrations\UndrawMobileEncryptionComponent::class => 'mobile-encryption',
            \BladeComponents\Undraw\Components\Illustrations\UndrawMobileFeedComponent::class => 'mobile-feed',
            \BladeComponents\Undraw\Components\Illustrations\UndrawMobileImagesComponent::class => 'mobile-images',
            \BladeComponents\Undraw\Components\Illustrations\UndrawMobileInboxComponent::class => 'mobile-inbox',
            \BladeComponents\Undraw\Components\Illustrations\UndrawMobileInterfaceComponent::class => 'mobile-interface',
            \BladeComponents\Undraw\Components\Illustrations\UndrawMobileLifeComponent::class => 'mobile-life',
            \BladeComponents\Undraw\Components\Illustrations\UndrawMobileLoginComponent::class => 'mobile-login',
            \BladeComponents\Undraw\Components\Illustrations\UndrawMobileMarketingComponent::class => 'mobile-marketing',
            \BladeComponents\Undraw\Components\Illustrations\UndrawMobileMessagesComponent::class => 'mobile-messages',
            \BladeComponents\Undraw\Components\Illustrations\UndrawMobilePayComponent::class => 'mobile-pay',
            \BladeComponents\Undraw\Components\Illustrations\UndrawMobilePaymentsComponent::class => 'mobile-payments',
            \BladeComponents\Undraw\Components\Illustrations\UndrawMobilePhotosComponent::class => 'mobile-photos',
            \BladeComponents\Undraw\Components\Illustrations\UndrawMobilePostsComponent::class => 'mobile-posts',
            \BladeComponents\Undraw\Components\Illustrations\UndrawMobilePrototypingComponent::class => 'mobile-prototyping',
            \BladeComponents\Undraw\Components\Illustrations\UndrawMobileSearchComponent::class => 'mobile-search',
            \BladeComponents\Undraw\Components\Illustrations\UndrawMobileTestingComponent::class => 'mobile-testing',
            \BladeComponents\Undraw\Components\Illustrations\UndrawMobileUserComponent::class => 'mobile-user',
            \BladeComponents\Undraw\Components\Illustrations\UndrawMobileUxComponent::class => 'mobile-ux',
            \BladeComponents\Undraw\Components\Illustrations\UndrawMobileWebComponent::class => 'mobile-web',
            \BladeComponents\Undraw\Components\Illustrations\UndrawMobileWireframeComponent::class => 'mobile-wireframe',
            \BladeComponents\Undraw\Components\Illustrations\UndrawModernArtComponent::class => 'modern-art',
            \BladeComponents\Undraw\Components\Illustrations\UndrawModernDesignComponent::class => 'modern-design',
            \BladeComponents\Undraw\Components\Illustrations\UndrawModernLifeComponent::class => 'modern-life',
            \BladeComponents\Undraw\Components\Illustrations\UndrawModernProfessionalComponent::class => 'modern-professional',
            \BladeComponents\Undraw\Components\Illustrations\UndrawModernWomanComponent::class => 'modern-woman',
            \BladeComponents\Undraw\Components\Illustrations\UndrawMomentToRememberComponent::class => 'moment-to-remember',
            \BladeComponents\Undraw\Components\Illustrations\UndrawMomentsComponent::class => 'moments',
            \BladeComponents\Undraw\Components\Illustrations\UndrawMonitorComponent::class => 'monitor',
            \BladeComponents\Undraw\Components\Illustrations\UndrawMonsterArtistComponent::class => 'monster-artist',
            \BladeComponents\Undraw\Components\Illustrations\UndrawMoonlightComponent::class => 'moonlight',
            \BladeComponents\Undraw\Components\Illustrations\UndrawMoreMusicComponent::class => 'more-music',
            \BladeComponents\Undraw\Components\Illustrations\UndrawMorningsComponent::class => 'mornings',
            \BladeComponents\Undraw\Components\Illustrations\UndrawMotherhoodComponent::class => 'motherhood',
            \BladeComponents\Undraw\Components\Illustrations\UndrawMovieNightComponent::class => 'movie-night',
            \BladeComponents\Undraw\Components\Illustrations\UndrawMovingComponent::class => 'moving',
            \BladeComponents\Undraw\Components\Illustrations\UndrawMovingForwardComponent::class => 'moving-forward',
            \BladeComponents\Undraw\Components\Illustrations\UndrawMultitaskingComponent::class => 'multitasking',
            \BladeComponents\Undraw\Components\Illustrations\UndrawMusicComponent::class => 'music',
            \BladeComponents\Undraw\Components\Illustrations\UndrawMyAnswerComponent::class => 'my-answer',
            \BladeComponents\Undraw\Components\Illustrations\UndrawMyAppComponent::class => 'my-app',
            \BladeComponents\Undraw\Components\Illustrations\UndrawMyCodeSnippetsComponent::class => 'my-code-snippets',
            \BladeComponents\Undraw\Components\Illustrations\UndrawMyCurrentLocationComponent::class => 'my-current-location',
            \BladeComponents\Undraw\Components\Illustrations\UndrawMyDocumentsComponent::class => 'my-documents',
            \BladeComponents\Undraw\Components\Illustrations\UndrawMyFeedComponent::class => 'my-feed',
            \BladeComponents\Undraw\Components\Illustrations\UndrawMyFilesComponent::class => 'my-files',
            \BladeComponents\Undraw\Components\Illustrations\UndrawMyLocationComponent::class => 'my-location',
            \BladeComponents\Undraw\Components\Illustrations\UndrawMyNotificationsComponent::class => 'my-notifications',
            \BladeComponents\Undraw\Components\Illustrations\UndrawMyPasswordComponent::class => 'my-password',
            \BladeComponents\Undraw\Components\Illustrations\UndrawMyPersonalFilesComponent::class => 'my-personal-files',
            \BladeComponents\Undraw\Components\Illustrations\UndrawMyUniverseComponent::class => 'my-universe',
            \BladeComponents\Undraw\Components\Illustrations\UndrawNakamotoComponent::class => 'nakamoto',
            \BladeComponents\Undraw\Components\Illustrations\UndrawNatureBenefitsComponent::class => 'nature-benefits',
            \BladeComponents\Undraw\Components\Illustrations\UndrawNatureComponent::class => 'nature',
            \BladeComponents\Undraw\Components\Illustrations\UndrawNatureFunComponent::class => 'nature-fun',
            \BladeComponents\Undraw\Components\Illustrations\UndrawNatureOnScreenComponent::class => 'nature-on-screen',
            \BladeComponents\Undraw\Components\Illustrations\UndrawNavigationComponent::class => 'navigation',
            \BladeComponents\Undraw\Components\Illustrations\UndrawNavigatorComponent::class => 'navigator',
            \BladeComponents\Undraw\Components\Illustrations\UndrawNeighborsComponent::class => 'neighbors',
            \BladeComponents\Undraw\Components\Illustrations\UndrawNetflixComponent::class => 'netflix',
            \BladeComponents\Undraw\Components\Illustrations\UndrawNewDecadeComponent::class => 'new-decade',
            \BladeComponents\Undraw\Components\Illustrations\UndrawNewEntriesComponent::class => 'new-entries',
            \BladeComponents\Undraw\Components\Illustrations\UndrawNewIdeasComponent::class => 'new-ideas',
            \BladeComponents\Undraw\Components\Illustrations\UndrawNewMessageComponent::class => 'new-message',
            \BladeComponents\Undraw\Components\Illustrations\UndrawNewNotificationsComponent::class => 'new-notifications',
            \BladeComponents\Undraw\Components\Illustrations\UndrawNewYear2021Component::class => 'new-year-2021',
            \BladeComponents\Undraw\Components\Illustrations\UndrawNewYear2022Component::class => 'new-year-2022',
            \BladeComponents\Undraw\Components\Illustrations\UndrawNewYear2023Component::class => 'new-year-2023',
            \BladeComponents\Undraw\Components\Illustrations\UndrawNewsComponent::class => 'news',
            \BladeComponents\Undraw\Components\Illustrations\UndrawNewsletterComponent::class => 'newsletter',
            \BladeComponents\Undraw\Components\Illustrations\UndrawNewspaperComponent::class => 'newspaper',
            \BladeComponents\Undraw\Components\Illustrations\UndrawNextJsComponent::class => 'nextjs',
            \BladeComponents\Undraw\Components\Illustrations\UndrawNextOptionComponent::class => 'next-option',
            \BladeComponents\Undraw\Components\Illustrations\UndrawNextTasksComponent::class => 'next-tasks',
            \BladeComponents\Undraw\Components\Illustrations\UndrawNightCallsComponent::class => 'night-calls',
            \BladeComponents\Undraw\Components\Illustrations\UndrawNinjaComponent::class => 'ninja',
            \BladeComponents\Undraw\Components\Illustrations\UndrawNoDataComponent::class => 'no-data',
            \BladeComponents\Undraw\Components\Illustrations\UndrawNotFoundComponent::class => 'not-found',
            \BladeComponents\Undraw\Components\Illustrations\UndrawNoteListComponent::class => 'note-list',
            \BladeComponents\Undraw\Components\Illustrations\UndrawNotebookComponent::class => 'notebook',
            \BladeComponents\Undraw\Components\Illustrations\UndrawNotedComponent::class => 'noted',
            \BladeComponents\Undraw\Components\Illustrations\UndrawNotesComponent::class => 'notes',
            \BladeComponents\Undraw\Components\Illustrations\UndrawNotifyComponent::class => 'notify',
            \BladeComponents\Undraw\Components\Illustrations\UndrawNuxtJsComponent::class => 'nuxt-js',
            \BladeComponents\Undraw\Components\Illustrations\UndrawOSUpgradeComponent::class => 'os-upgrade',
            \BladeComponents\Undraw\Components\Illustrations\UndrawObservationsComponent::class => 'observations',
            \BladeComponents\Undraw\Components\Illustrations\UndrawOffRoadComponent::class => 'off-road',
            \BladeComponents\Undraw\Components\Illustrations\UndrawOfficeSnackComponent::class => 'office-snack',
            \BladeComponents\Undraw\Components\Illustrations\UndrawOmegaComponent::class => 'omega',
            \BladeComponents\Undraw\Components\Illustrations\UndrawOnTheOfficeComponent::class => 'on-the-office',
            \BladeComponents\Undraw\Components\Illustrations\UndrawOnTheWayComponent::class => 'on-the-way',
            \BladeComponents\Undraw\Components\Illustrations\UndrawOnboardingComponent::class => 'onboarding',
            \BladeComponents\Undraw\Components\Illustrations\UndrawOnlineAdComponent::class => 'online-ad',
            \BladeComponents\Undraw\Components\Illustrations\UndrawOnlineArtComponent::class => 'online-art',
            \BladeComponents\Undraw\Components\Illustrations\UndrawOnlineArticleComponent::class => 'online-article',
            \BladeComponents\Undraw\Components\Illustrations\UndrawOnlineArticlesComponent::class => 'online-articles',
            \BladeComponents\Undraw\Components\Illustrations\UndrawOnlineBankingComponent::class => 'online-banking',
            \BladeComponents\Undraw\Components\Illustrations\UndrawOnlineCalendarComponent::class => 'online-calendar',
            \BladeComponents\Undraw\Components\Illustrations\UndrawOnlineChatComponent::class => 'online-chat',
            \BladeComponents\Undraw\Components\Illustrations\UndrawOnlineCollaborationComponent::class => 'online-collaboration',
            \BladeComponents\Undraw\Components\Illustrations\UndrawOnlineComponent::class => 'online',
            \BladeComponents\Undraw\Components\Illustrations\UndrawOnlineConnectionComponent::class => 'online-connection',
            \BladeComponents\Undraw\Components\Illustrations\UndrawOnlineCvComponent::class => 'online-cv',
            \BladeComponents\Undraw\Components\Illustrations\UndrawOnlineDatingComponent::class => 'online-dating',
            \BladeComponents\Undraw\Components\Illustrations\UndrawOnlineDiscussionComponent::class => 'online-discussion',
            \BladeComponents\Undraw\Components\Illustrations\UndrawOnlineEverywhereComponent::class => 'online-everywhere',
            \BladeComponents\Undraw\Components\Illustrations\UndrawOnlineFriendsComponent::class => 'online-friends',
            \BladeComponents\Undraw\Components\Illustrations\UndrawOnlineGalleryComponent::class => 'online-gallery',
            \BladeComponents\Undraw\Components\Illustrations\UndrawOnlineGroceriesComponent::class => 'online-groceries',
            \BladeComponents\Undraw\Components\Illustrations\UndrawOnlineInformationComponent::class => 'online-information',
            \BladeComponents\Undraw\Components\Illustrations\UndrawOnlineLearningComponent::class => 'online-learning',
            \BladeComponents\Undraw\Components\Illustrations\UndrawOnlineMediaComponent::class => 'online-media',
            \BladeComponents\Undraw\Components\Illustrations\UndrawOnlineMessageComponent::class => 'online-message',
            \BladeComponents\Undraw\Components\Illustrations\UndrawOnlineMessagingComponent::class => 'online-messaging',
            \BladeComponents\Undraw\Components\Illustrations\UndrawOnlineOrganizerComponent::class => 'online-organizer',
            \BladeComponents\Undraw\Components\Illustrations\UndrawOnlinePageComponent::class => 'online-page',
            \BladeComponents\Undraw\Components\Illustrations\UndrawOnlinePartyComponent::class => 'online-party',
            \BladeComponents\Undraw\Components\Illustrations\UndrawOnlinePaymentsComponent::class => 'online-payments',
            \BladeComponents\Undraw\Components\Illustrations\UndrawOnlinePopularityComponent::class => 'online-popularity',
            \BladeComponents\Undraw\Components\Illustrations\UndrawOnlinePostsComponent::class => 'online-posts',
            \BladeComponents\Undraw\Components\Illustrations\UndrawOnlineReadingComponent::class => 'online-reading',
            \BladeComponents\Undraw\Components\Illustrations\UndrawOnlineResumeComponent::class => 'online-resume',
            \BladeComponents\Undraw\Components\Illustrations\UndrawOnlineShoppingComponent::class => 'online-shopping',
            \BladeComponents\Undraw\Components\Illustrations\UndrawOnlineStatsComponent::class => 'online-stats',
            \BladeComponents\Undraw\Components\Illustrations\UndrawOnlineTestComponent::class => 'online-test',
            \BladeComponents\Undraw\Components\Illustrations\UndrawOnlineTransactionsComponent::class => 'online-transactions',
            \BladeComponents\Undraw\Components\Illustrations\UndrawOnlineVideoComponent::class => 'online-video',
            \BladeComponents\Undraw\Components\Illustrations\UndrawOnlineWishesComponent::class => 'online-wishes',
            \BladeComponents\Undraw\Components\Illustrations\UndrawOnlineWorldComponent::class => 'online-world',
            \BladeComponents\Undraw\Components\Illustrations\UndrawOpenSourceComponent::class => 'open-source',
            \BladeComponents\Undraw\Components\Illustrations\UndrawOpenedComponent::class => 'opened',
            \BladeComponents\Undraw\Components\Illustrations\UndrawOpenedTabsComponent::class => 'opened-tabs',
            \BladeComponents\Undraw\Components\Illustrations\UndrawOpinionComponent::class => 'opinion',
            \BladeComponents\Undraw\Components\Illustrations\UndrawOptimizeImageComponent::class => 'optimize-image',
            \BladeComponents\Undraw\Components\Illustrations\UndrawOptionsComponent::class => 'options',
            \BladeComponents\Undraw\Components\Illustrations\UndrawOrderACarComponent::class => 'order-a-car',
            \BladeComponents\Undraw\Components\Illustrations\UndrawOrderConfirmedComponent::class => 'order-confirmed',
            \BladeComponents\Undraw\Components\Illustrations\UndrawOrderDeliveredComponent::class => 'order-delivered',
            \BladeComponents\Undraw\Components\Illustrations\UndrawOrderRideComponent::class => 'order-ride',
            \BladeComponents\Undraw\Components\Illustrations\UndrawOrdinaryDayComponent::class => 'ordinary-day',
            \BladeComponents\Undraw\Components\Illustrations\UndrawOrganizePhotosComponent::class => 'organize-photos',
            \BladeComponents\Undraw\Components\Illustrations\UndrawOrganizeResumeComponent::class => 'organize-resume',
            \BladeComponents\Undraw\Components\Illustrations\UndrawOrganizedContentComponent::class => 'organized-content',
            \BladeComponents\Undraw\Components\Illustrations\UndrawOrganizingProjectsComponent::class => 'organizing-projects',
            \BladeComponents\Undraw\Components\Illustrations\UndrawOurNeighborhoodComponent::class => 'our-neighborhood',
            \BladeComponents\Undraw\Components\Illustrations\UndrawOurSolutionComponent::class => 'our-solution',
            \BladeComponents\Undraw\Components\Illustrations\UndrawOutdoorAdventureComponent::class => 'outdoor-adventure',
            \BladeComponents\Undraw\Components\Illustrations\UndrawOutdoorPartyComponent::class => 'outdoor-party',
            \BladeComponents\Undraw\Components\Illustrations\UndrawOutdoorsComponent::class => 'outdoors',
            \BladeComponents\Undraw\Components\Illustrations\UndrawOuterSpaceComponent::class => 'outer-space',
            \BladeComponents\Undraw\Components\Illustrations\UndrawPackageArrivedComponent::class => 'package-arrived',
            \BladeComponents\Undraw\Components\Illustrations\UndrawPageNotFoundComponent::class => 'page-not-found',
            \BladeComponents\Undraw\Components\Illustrations\UndrawPairProgrammingComponent::class => 'pair-programming',
            \BladeComponents\Undraw\Components\Illustrations\UndrawPaletteComponent::class => 'palette',
            \BladeComponents\Undraw\Components\Illustrations\UndrawPancakesComponent::class => 'pancakes',
            \BladeComponents\Undraw\Components\Illustrations\UndrawPartyComponent::class => 'party',
            \BladeComponents\Undraw\Components\Illustrations\UndrawPartyingComponent::class => 'partying',
            \BladeComponents\Undraw\Components\Illustrations\UndrawPassingByComponent::class => 'passing-by',
            \BladeComponents\Undraw\Components\Illustrations\UndrawPayOnlineComponent::class => 'pay-online',
            \BladeComponents\Undraw\Components\Illustrations\UndrawPaymentsComponent::class => 'payments',
            \BladeComponents\Undraw\Components\Illustrations\UndrawPedestrianCrossingComponent::class => 'pedestrian-crossing',
            \BladeComponents\Undraw\Components\Illustrations\UndrawPenToolComponent::class => 'pen-tool',
            \BladeComponents\Undraw\Components\Illustrations\UndrawPendingApprovalComponent::class => 'pending-approval',
            \BladeComponents\Undraw\Components\Illustrations\UndrawPeopleComponent::class => 'people',
            \BladeComponents\Undraw\Components\Illustrations\UndrawPeopleSearchComponent::class => 'people-search',
            \BladeComponents\Undraw\Components\Illustrations\UndrawPercentagesComponent::class => 'percentages',
            \BladeComponents\Undraw\Components\Illustrations\UndrawPerformanceOverviewComponent::class => 'performance-overview',
            \BladeComponents\Undraw\Components\Illustrations\UndrawPersonalDataComponent::class => 'personal-data',
            \BladeComponents\Undraw\Components\Illustrations\UndrawPersonalDocumentsComponent::class => 'personal-documents',
            \BladeComponents\Undraw\Components\Illustrations\UndrawPersonalEmailComponent::class => 'personal-email',
            \BladeComponents\Undraw\Components\Illustrations\UndrawPersonalFileComponent::class => 'personal-file',
            \BladeComponents\Undraw\Components\Illustrations\UndrawPersonalFinanceComponent::class => 'personal-finance',
            \BladeComponents\Undraw\Components\Illustrations\UndrawPersonalGoalsComponent::class => 'personal-goals',
            \BladeComponents\Undraw\Components\Illustrations\UndrawPersonalInfoComponent::class => 'personal-info',
            \BladeComponents\Undraw\Components\Illustrations\UndrawPersonalInformationComponent::class => 'personal-information',
            \BladeComponents\Undraw\Components\Illustrations\UndrawPersonalNotebookComponent::class => 'personal-notebook',
            \BladeComponents\Undraw\Components\Illustrations\UndrawPersonalNotesComponent::class => 'personal-notes',
            \BladeComponents\Undraw\Components\Illustrations\UndrawPersonalOpinionsComponent::class => 'personal-opinions',
            \BladeComponents\Undraw\Components\Illustrations\UndrawPersonalSettingsComponent::class => 'personal-settings',
            \BladeComponents\Undraw\Components\Illustrations\UndrawPersonalSiteComponent::class => 'personal-site',
            \BladeComponents\Undraw\Components\Illustrations\UndrawPersonalTextComponent::class => 'personal-text',
            \BladeComponents\Undraw\Components\Illustrations\UndrawPersonalTrainerComponent::class => 'personal-trainer',
            \BladeComponents\Undraw\Components\Illustrations\UndrawPersonalTrainingComponent::class => 'personal-training',
            \BladeComponents\Undraw\Components\Illustrations\UndrawPersonalWebsiteComponent::class => 'personal-website',
            \BladeComponents\Undraw\Components\Illustrations\UndrawPersonalizationComponent::class => 'personalization',
            \BladeComponents\Undraw\Components\Illustrations\UndrawPetAdoptionComponent::class => 'pet-adoption',
            \BladeComponents\Undraw\Components\Illustrations\UndrawPhoneCallComponent::class => 'phone-call',
            \BladeComponents\Undraw\Components\Illustrations\UndrawPhotoAlbumComponent::class => 'photo-album',
            \BladeComponents\Undraw\Components\Illustrations\UndrawPhotoComponent::class => 'photo',
            \BladeComponents\Undraw\Components\Illustrations\UndrawPhotoSessionComponent::class => 'photo-session',
            \BladeComponents\Undraw\Components\Illustrations\UndrawPhotoSharingComponent::class => 'photo-sharing',
            \BladeComponents\Undraw\Components\Illustrations\UndrawPhotocopyComponent::class => 'photocopy',
            \BladeComponents\Undraw\Components\Illustrations\UndrawPhotographComponent::class => 'photograph',
            \BladeComponents\Undraw\Components\Illustrations\UndrawPhotosComponent::class => 'photos',
            \BladeComponents\Undraw\Components\Illustrations\UndrawPicProfileComponent::class => 'pic-profile',
            \BladeComponents\Undraw\Components\Illustrations\UndrawPictureComponent::class => 'picture',
            \BladeComponents\Undraw\Components\Illustrations\UndrawPieChartComponent::class => 'pie-chart',
            \BladeComponents\Undraw\Components\Illustrations\UndrawPieGraphComponent::class => 'pie-graph',
            \BladeComponents\Undraw\Components\Illustrations\UndrawPilatesComponent::class => 'pilates',
            \BladeComponents\Undraw\Components\Illustrations\UndrawPitchingComponent::class => 'pitching',
            \BladeComponents\Undraw\Components\Illustrations\UndrawPizzaSharingComponent::class => 'pizza-sharing',
            \BladeComponents\Undraw\Components\Illustrations\UndrawPlaceholdersComponent::class => 'placeholders',
            \BladeComponents\Undraw\Components\Illustrations\UndrawPlainCreditCardComponent::class => 'plain-credit-card',
            \BladeComponents\Undraw\Components\Illustrations\UndrawPlansComponent::class => 'plans',
            \BladeComponents\Undraw\Components\Illustrations\UndrawPlayTimeComponent::class => 'play-time',
            \BladeComponents\Undraw\Components\Illustrations\UndrawPlayfulCatComponent::class => 'playful-cat',
            \BladeComponents\Undraw\Components\Illustrations\UndrawPlayingCardsComponent::class => 'playing-cards',
            \BladeComponents\Undraw\Components\Illustrations\UndrawPlayingFetchComponent::class => 'playing-fetch',
            \BladeComponents\Undraw\Components\Illustrations\UndrawPlayingGolfComponent::class => 'playing-golf',
            \BladeComponents\Undraw\Components\Illustrations\UndrawPlaylistComponent::class => 'playlist',
            \BladeComponents\Undraw\Components\Illustrations\UndrawPleasantSurpriseComponent::class => 'pleasant-surprise',
            \BladeComponents\Undraw\Components\Illustrations\UndrawPodcastAudienceComponent::class => 'podcast-audience',
            \BladeComponents\Undraw\Components\Illustrations\UndrawPodcastComponent::class => 'podcast',
            \BladeComponents\Undraw\Components\Illustrations\UndrawPolaroidComponent::class => 'polaroid',
            \BladeComponents\Undraw\Components\Illustrations\UndrawPopularComponent::class => 'popular',
            \BladeComponents\Undraw\Components\Illustrations\UndrawPortfolioComponent::class => 'portfolio',
            \BladeComponents\Undraw\Components\Illustrations\UndrawPortfolioFeedbackComponent::class => 'portfolio-feedback',
            \BladeComponents\Undraw\Components\Illustrations\UndrawPortfolioUpdateComponent::class => 'portfolio-update',
            \BladeComponents\Undraw\Components\Illustrations\UndrawPortfolioWebsiteComponent::class => 'portfolio-website',
            \BladeComponents\Undraw\Components\Illustrations\UndrawPositiveAttitudeComponent::class => 'positive-attitude',
            \BladeComponents\Undraw\Components\Illustrations\UndrawPostComponent::class => 'post',
            \BladeComponents\Undraw\Components\Illustrations\UndrawPostOnlineComponent::class => 'post-online',
            \BladeComponents\Undraw\Components\Illustrations\UndrawPostingPhotoComponent::class => 'posting-photo',
            \BladeComponents\Undraw\Components\Illustrations\UndrawPostsComponent::class => 'posts',
            \BladeComponents\Undraw\Components\Illustrations\UndrawPowerfulComponent::class => 'powerful',
            \BladeComponents\Undraw\Components\Illustrations\UndrawPredictiveAnalyticsComponent::class => 'predictive-analytics',
            \BladeComponents\Undraw\Components\Illustrations\UndrawPreferencesComponent::class => 'preferences',
            \BladeComponents\Undraw\Components\Illustrations\UndrawPreferencesPopupComponent::class => 'preferences-popup',
            \BladeComponents\Undraw\Components\Illustrations\UndrawPreparationComponent::class => 'preparation',
            \BladeComponents\Undraw\Components\Illustrations\UndrawPresentationComponent::class => 'presentation',
            \BladeComponents\Undraw\Components\Illustrations\UndrawPressPlayComponent::class => 'press-play',
            \BladeComponents\Undraw\Components\Illustrations\UndrawPrideComponent::class => 'pride',
            \BladeComponents\Undraw\Components\Illustrations\UndrawPrintingInvoicesComponent::class => 'printing-invoices',
            \BladeComponents\Undraw\Components\Illustrations\UndrawPrioritiseComponent::class => 'prioritise',
            \BladeComponents\Undraw\Components\Illustrations\UndrawPrivateDataComponent::class => 'private-data',
            \BladeComponents\Undraw\Components\Illustrations\UndrawProblemSolvingComponent::class => 'problem-solving',
            \BladeComponents\Undraw\Components\Illustrations\UndrawProcessComponent::class => 'process',
            \BladeComponents\Undraw\Components\Illustrations\UndrawProcessingComponent::class => 'processing',
            \BladeComponents\Undraw\Components\Illustrations\UndrawProcessingThoughtsComponent::class => 'processing-thoughts',
            \BladeComponents\Undraw\Components\Illustrations\UndrawProductExplainerComponent::class => 'product-explainer',
            \BladeComponents\Undraw\Components\Illustrations\UndrawProductHuntComponent::class => 'product-hunt',
            \BladeComponents\Undraw\Components\Illustrations\UndrawProductIterationComponent::class => 'product-iteration',
            \BladeComponents\Undraw\Components\Illustrations\UndrawProductPhotographyComponent::class => 'product-photography',
            \BladeComponents\Undraw\Components\Illustrations\UndrawProductTeardownComponent::class => 'product-teardown',
            \BladeComponents\Undraw\Components\Illustrations\UndrawProductTourComponent::class => 'product-tour',
            \BladeComponents\Undraw\Components\Illustrations\UndrawProfessionalCardComponent::class => 'professional-card',
            \BladeComponents\Undraw\Components\Illustrations\UndrawProfessorComponent::class => 'professor',
            \BladeComponents\Undraw\Components\Illustrations\UndrawProfileComponent::class => 'profile',
            \BladeComponents\Undraw\Components\Illustrations\UndrawProfileDataComponent::class => 'profile-data',
            \BladeComponents\Undraw\Components\Illustrations\UndrawProfileDetailsComponent::class => 'profile-details',
            \BladeComponents\Undraw\Components\Illustrations\UndrawProfileImageComponent::class => 'profile-image',
            \BladeComponents\Undraw\Components\Illustrations\UndrawProfilePicComponent::class => 'profile-pic',
            \BladeComponents\Undraw\Components\Illustrations\UndrawProgrammerComponent::class => 'programmer',
            \BladeComponents\Undraw\Components\Illustrations\UndrawProgrammingComponent::class => 'programming',
            \BladeComponents\Undraw\Components\Illustrations\UndrawProgressDataComponent::class => 'progress-data',
            \BladeComponents\Undraw\Components\Illustrations\UndrawProgressIndicatorComponent::class => 'progress-indicator',
            \BladeComponents\Undraw\Components\Illustrations\UndrawProgressOverviewComponent::class => 'progress-overview',
            \BladeComponents\Undraw\Components\Illustrations\UndrawProgressTrackingComponent::class => 'progress-tracking',
            \BladeComponents\Undraw\Components\Illustrations\UndrawProgressiveAppComponent::class => 'progressive-app',
            \BladeComponents\Undraw\Components\Illustrations\UndrawProjectCompleteComponent::class => 'project-complete',
            \BladeComponents\Undraw\Components\Illustrations\UndrawProjectCompletedComponent::class => 'project-completed',
            \BladeComponents\Undraw\Components\Illustrations\UndrawProjectFeedbackComponent::class => 'project-feedback',
            \BladeComponents\Undraw\Components\Illustrations\UndrawProjectTeamComponent::class => 'project-team',
            \BladeComponents\Undraw\Components\Illustrations\UndrawProjectionsComponent::class => 'projections',
            \BladeComponents\Undraw\Components\Illustrations\UndrawPrototypingProcessComponent::class => 'prototyping-process',
            \BladeComponents\Undraw\Components\Illustrations\UndrawProudCoderComponent::class => 'proud-coder',
            \BladeComponents\Undraw\Components\Illustrations\UndrawProudSelfComponent::class => 'proud-self',
            \BladeComponents\Undraw\Components\Illustrations\UndrawPublicDiscussionComponent::class => 'public-discussion',
            \BladeComponents\Undraw\Components\Illustrations\UndrawPublishArticleComponent::class => 'publish-article',
            \BladeComponents\Undraw\Components\Illustrations\UndrawPublishPostComponent::class => 'publish-post',
            \BladeComponents\Undraw\Components\Illustrations\UndrawPullRequestComponent::class => 'pull-request',
            \BladeComponents\Undraw\Components\Illustrations\UndrawPumpkinComponent::class => 'pumpkin',
            \BladeComponents\Undraw\Components\Illustrations\UndrawPureLoveComponent::class => 'pure-love',
            \BladeComponents\Undraw\Components\Illustrations\UndrawPushNotificationsComponent::class => 'push-notifications',
            \BladeComponents\Undraw\Components\Illustrations\UndrawQAEngineersComponent::class => 'qa-engineers',
            \BladeComponents\Undraw\Components\Illustrations\UndrawQualityTimeComponent::class => 'quality-time',
            \BladeComponents\Undraw\Components\Illustrations\UndrawQuestionsComponent::class => 'questions',
            \BladeComponents\Undraw\Components\Illustrations\UndrawQuickChatComponent::class => 'quick-chat',
            \BladeComponents\Undraw\Components\Illustrations\UndrawQuietTownComponent::class => 'quiet-town',
            \BladeComponents\Undraw\Components\Illustrations\UndrawQuittingTimeComponent::class => 'quitting-time',
            \BladeComponents\Undraw\Components\Illustrations\UndrawQuizComponent::class => 'quiz',
            \BladeComponents\Undraw\Components\Illustrations\UndrawRainingComponent::class => 'raining',
            \BladeComponents\Undraw\Components\Illustrations\UndrawRandomThoughtsComponent::class => 'random-thoughts',
            \BladeComponents\Undraw\Components\Illustrations\UndrawReactComponent::class => 'react',
            \BladeComponents\Undraw\Components\Illustrations\UndrawReadingBookComponent::class => 'reading-book',
            \BladeComponents\Undraw\Components\Illustrations\UndrawReadingComponent::class => 'reading',
            \BladeComponents\Undraw\Components\Illustrations\UndrawReadingListComponent::class => 'reading-list',
            \BladeComponents\Undraw\Components\Illustrations\UndrawReadingTimeComponent::class => 'reading-time',
            \BladeComponents\Undraw\Components\Illustrations\UndrawReadyForWavesComponent::class => 'ready-for-waves',
            \BladeComponents\Undraw\Components\Illustrations\UndrawRealTimeAnalyticsComponent::class => 'real-time-analytics',
            \BladeComponents\Undraw\Components\Illustrations\UndrawRealTimeCollaborationComponent::class => 'real-time-collaboration',
            \BladeComponents\Undraw\Components\Illustrations\UndrawRealTimeSyncComponent::class => 'real-time-sync',
            \BladeComponents\Undraw\Components\Illustrations\UndrawReceiptComponent::class => 'receipt',
            \BladeComponents\Undraw\Components\Illustrations\UndrawRecordingComponent::class => 'recording',
            \BladeComponents\Undraw\Components\Illustrations\UndrawRedesignFeedbackComponent::class => 'redesign-feedback',
            \BladeComponents\Undraw\Components\Illustrations\UndrawReferralComponent::class => 'referral',
            \BladeComponents\Undraw\Components\Illustrations\UndrawRefreshingBeverageComponent::class => 'refreshing-beverage',
            \BladeComponents\Undraw\Components\Illustrations\UndrawRefreshingComponent::class => 'refreshing',
            \BladeComponents\Undraw\Components\Illustrations\UndrawRegainFocusComponent::class => 'regain-focus',
            \BladeComponents\Undraw\Components\Illustrations\UndrawRelaunchDayComponent::class => 'relaunch-day',
            \BladeComponents\Undraw\Components\Illustrations\UndrawRelaxationComponent::class => 'relaxation',
            \BladeComponents\Undraw\Components\Illustrations\UndrawRelaxingAtHomeComponent::class => 'relaxing-at-home',
            \BladeComponents\Undraw\Components\Illustrations\UndrawRelaxingWalkComponent::class => 'relaxing-walk',
            \BladeComponents\Undraw\Components\Illustrations\UndrawReminderComponent::class => 'reminder',
            \BladeComponents\Undraw\Components\Illustrations\UndrawRemindersComponent::class => 'reminders',
            \BladeComponents\Undraw\Components\Illustrations\UndrawRemoteDesignTeamComponent::class => 'remote-design-team',
            \BladeComponents\Undraw\Components\Illustrations\UndrawRemoteMeetingComponent::class => 'remote-meeting',
            \BladeComponents\Undraw\Components\Illustrations\UndrawRemoteTeamComponent::class => 'remote-team',
            \BladeComponents\Undraw\Components\Illustrations\UndrawRemotelyComponent::class => 'remotely',
            \BladeComponents\Undraw\Components\Illustrations\UndrawReportComponent::class => 'report',
            \BladeComponents\Undraw\Components\Illustrations\UndrawResearchingComponent::class => 'researching',
            \BladeComponents\Undraw\Components\Illustrations\UndrawRespondComponent::class => 'respond',
            \BladeComponents\Undraw\Components\Illustrations\UndrawResponsiveComponent::class => 'responsive',
            \BladeComponents\Undraw\Components\Illustrations\UndrawResponsivenessComponent::class => 'responsiveness',
            \BladeComponents\Undraw\Components\Illustrations\UndrawResultComponent::class => 'result',
            \BladeComponents\Undraw\Components\Illustrations\UndrawResumeComponent::class => 'resume',
            \BladeComponents\Undraw\Components\Illustrations\UndrawResumeFolderComponent::class => 'resume-folder',
            \BladeComponents\Undraw\Components\Illustrations\UndrawRevenueComponent::class => 'revenue',
            \BladeComponents\Undraw\Components\Illustrations\UndrawReviewComponent::class => 'review',
            \BladeComponents\Undraw\Components\Illustrations\UndrawReviewedDocsComponent::class => 'reviewed-docs',
            \BladeComponents\Undraw\Components\Illustrations\UndrawReviewsComponent::class => 'reviews',
            \BladeComponents\Undraw\Components\Illustrations\UndrawRideABicycleComponent::class => 'ride-a-bicycle',
            \BladeComponents\Undraw\Components\Illustrations\UndrawRideTillICanNoMoreComponent::class => 'ride-till-i-can-no-more',
            \BladeComponents\Undraw\Components\Illustrations\UndrawRightDirectionComponent::class => 'right-direction',
            \BladeComponents\Undraw\Components\Illustrations\UndrawRightPlacesComponent::class => 'right-places',
            \BladeComponents\Undraw\Components\Illustrations\UndrawRisingComponent::class => 'rising',
            \BladeComponents\Undraw\Components\Illustrations\UndrawRoadSignComponent::class => 'road-sign',
            \BladeComponents\Undraw\Components\Illustrations\UndrawRoadToKnowledgeComponent::class => 'road-to-knowledge',
            \BladeComponents\Undraw\Components\Illustrations\UndrawRoboticsComponent::class => 'robotics',
            \BladeComponents\Undraw\Components\Illustrations\UndrawRomanticGetawayComponent::class => 'romantic-getaway',
            \BladeComponents\Undraw\Components\Illustrations\UndrawRunnerStartComponent::class => 'runner-start',
            \BladeComponents\Undraw\Components\Illustrations\UndrawRunningWildComponent::class => 'running-wild',
            \BladeComponents\Undraw\Components\Illustrations\UndrawSafeComponent::class => 'safe',
            \BladeComponents\Undraw\Components\Illustrations\UndrawSantaClausComponent::class => 'santa-claus',
            \BladeComponents\Undraw\Components\Illustrations\UndrawSantaVisitComponent::class => 'santa-visit',
            \BladeComponents\Undraw\Components\Illustrations\UndrawSaveToBookmarksComponent::class => 'save-to-bookmarks',
            \BladeComponents\Undraw\Components\Illustrations\UndrawSavingsComponent::class => 'savings',
            \BladeComponents\Undraw\Components\Illustrations\UndrawScheduleComponent::class => 'schedule',
            \BladeComponents\Undraw\Components\Illustrations\UndrawScheduleMeetingComponent::class => 'schedule-meeting',
            \BladeComponents\Undraw\Components\Illustrations\UndrawScienceComponent::class => 'science',
            \BladeComponents\Undraw\Components\Illustrations\UndrawScientistComponent::class => 'scientist',
            \BladeComponents\Undraw\Components\Illustrations\UndrawScooterComponent::class => 'scooter',
            \BladeComponents\Undraw\Components\Illustrations\UndrawScreenTimeComponent::class => 'screen-time',
            \BladeComponents\Undraw\Components\Illustrations\UndrawScrumBoardComponent::class => 'scrum-board',
            \BladeComponents\Undraw\Components\Illustrations\UndrawSculptingComponent::class => 'sculpting',
            \BladeComponents\Undraw\Components\Illustrations\UndrawSearchAppComponent::class => 'search-app',
            \BladeComponents\Undraw\Components\Illustrations\UndrawSearchComponent::class => 'search',
            \BladeComponents\Undraw\Components\Illustrations\UndrawSearchEnginesComponent::class => 'search-engines',
            \BladeComponents\Undraw\Components\Illustrations\UndrawSearchingComponent::class => 'searching',
            \BladeComponents\Undraw\Components\Illustrations\UndrawSeasonChangeComponent::class => 'season-change',
            \BladeComponents\Undraw\Components\Illustrations\UndrawSecureFilesComponent::class => 'secure-files',
            \BladeComponents\Undraw\Components\Illustrations\UndrawSecureLoginComponent::class => 'secure-login',
            \BladeComponents\Undraw\Components\Illustrations\UndrawSecureServerComponent::class => 'secure-server',
            \BladeComponents\Undraw\Components\Illustrations\UndrawSecurityComponent::class => 'security',
            \BladeComponents\Undraw\Components\Illustrations\UndrawSecurityOnComponent::class => 'security-on',
            \BladeComponents\Undraw\Components\Illustrations\UndrawSegmentAnalysisComponent::class => 'segment-analysis',
            \BladeComponents\Undraw\Components\Illustrations\UndrawSegmentComponent::class => 'segment',
            \BladeComponents\Undraw\Components\Illustrations\UndrawSegmentationComponent::class => 'segmentation',
            \BladeComponents\Undraw\Components\Illustrations\UndrawSelectComponent::class => 'select',
            \BladeComponents\Undraw\Components\Illustrations\UndrawSelectHouseComponent::class => 'select-house',
            \BladeComponents\Undraw\Components\Illustrations\UndrawSelectOptionComponent::class => 'select-option',
            \BladeComponents\Undraw\Components\Illustrations\UndrawSelectPlayerComponent::class => 'select-player',
            \BladeComponents\Undraw\Components\Illustrations\UndrawSelectedOptionsComponent::class => 'selected-options',
            \BladeComponents\Undraw\Components\Illustrations\UndrawSelectingComponent::class => 'selecting',
            \BladeComponents\Undraw\Components\Illustrations\UndrawSelectingTeamComponent::class => 'selecting-team',
            \BladeComponents\Undraw\Components\Illustrations\UndrawSelectionComponent::class => 'selection',
            \BladeComponents\Undraw\Components\Illustrations\UndrawSelfieComponent::class => 'selfie',
            \BladeComponents\Undraw\Components\Illustrations\UndrawSelfieTimeComponent::class => 'selfie-time',
            \BladeComponents\Undraw\Components\Illustrations\UndrawSendGiftComponent::class => 'send-gift',
            \BladeComponents\Undraw\Components\Illustrations\UndrawSentimentAnalysisComponent::class => 'sentiment-analysis',
            \BladeComponents\Undraw\Components\Illustrations\UndrawServerClusterComponent::class => 'server-cluster',
            \BladeComponents\Undraw\Components\Illustrations\UndrawServerComponent::class => 'server',
            \BladeComponents\Undraw\Components\Illustrations\UndrawServerDownComponent::class => 'server-down',
            \BladeComponents\Undraw\Components\Illustrations\UndrawServerPushComponent::class => 'server-push',
            \BladeComponents\Undraw\Components\Illustrations\UndrawServerStatusComponent::class => 'server-status',
            \BladeComponents\Undraw\Components\Illustrations\UndrawServicesComponent::class => 'services',
            \BladeComponents\Undraw\Components\Illustrations\UndrawSetPreferencesComponent::class => 'set-preferences',
            \BladeComponents\Undraw\Components\Illustrations\UndrawSettingsComponent::class => 'settings',
            \BladeComponents\Undraw\Components\Illustrations\UndrawSettingsTabComponent::class => 'settings-tab',
            \BladeComponents\Undraw\Components\Illustrations\UndrawSetupAnalyticsComponent::class => 'setup-analytics',
            \BladeComponents\Undraw\Components\Illustrations\UndrawSetupComponent::class => 'setup',
            \BladeComponents\Undraw\Components\Illustrations\UndrawSetupWizardComponent::class => 'setup-wizard',
            \BladeComponents\Undraw\Components\Illustrations\UndrawShareComponent::class => 'share',
            \BladeComponents\Undraw\Components\Illustrations\UndrawShareLinkComponent::class => 'share-link',
            \BladeComponents\Undraw\Components\Illustrations\UndrawShareOnlineComponent::class => 'share-online',
            \BladeComponents\Undraw\Components\Illustrations\UndrawShareOpinionComponent::class => 'share-opinion',
            \BladeComponents\Undraw\Components\Illustrations\UndrawSharedGoalsComponent::class => 'shared-goals',
            \BladeComponents\Undraw\Components\Illustrations\UndrawSharedWorkspaceComponent::class => 'shared-workspace',
            \BladeComponents\Undraw\Components\Illustrations\UndrawSharingArticlesComponent::class => 'sharing-articles',
            \BladeComponents\Undraw\Components\Illustrations\UndrawSharingKnowledgeComponent::class => 'sharing-knowledge',
            \BladeComponents\Undraw\Components\Illustrations\UndrawShoppingAppComponent::class => 'shopping-app',
            \BladeComponents\Undraw\Components\Illustrations\UndrawShoppingBagsComponent::class => 'shopping-bags',
            \BladeComponents\Undraw\Components\Illustrations\UndrawShoppingComponent::class => 'shopping',
            \BladeComponents\Undraw\Components\Illustrations\UndrawShortBioComponent::class => 'short-bio',
            \BladeComponents\Undraw\Components\Illustrations\UndrawShowingSupportComponent::class => 'showing-support',
            \BladeComponents\Undraw\Components\Illustrations\UndrawSignInComponent::class => 'sign-in',
            \BladeComponents\Undraw\Components\Illustrations\UndrawSignUpComponent::class => 'sign-up',
            \BladeComponents\Undraw\Components\Illustrations\UndrawSignalSearchingComponent::class => 'signal-searching',
            \BladeComponents\Undraw\Components\Illustrations\UndrawSiteContentComponent::class => 'site-content',
            \BladeComponents\Undraw\Components\Illustrations\UndrawSiteStatsComponent::class => 'site-stats',
            \BladeComponents\Undraw\Components\Illustrations\UndrawSkateboardComponent::class => 'skateboard',
            \BladeComponents\Undraw\Components\Illustrations\UndrawSkateboardingComponent::class => 'skateboarding',
            \BladeComponents\Undraw\Components\Illustrations\UndrawSliderComponent::class => 'slider',
            \BladeComponents\Undraw\Components\Illustrations\UndrawSmallTownComponent::class => 'small-town',
            \BladeComponents\Undraw\Components\Illustrations\UndrawSmartHomeComponent::class => 'smart-home',
            \BladeComponents\Undraw\Components\Illustrations\UndrawSmartResizeComponent::class => 'smart-resize',
            \BladeComponents\Undraw\Components\Illustrations\UndrawSmartwatchComponent::class => 'smartwatch',
            \BladeComponents\Undraw\Components\Illustrations\UndrawSmileyFaceComponent::class => 'smiley-face',
            \BladeComponents\Undraw\Components\Illustrations\UndrawSnapTheMomentComponent::class => 'snap-the-moment',
            \BladeComponents\Undraw\Components\Illustrations\UndrawSnowFunComponent::class => 'snow-fun',
            \BladeComponents\Undraw\Components\Illustrations\UndrawSnowGamesComponent::class => 'snow-games',
            \BladeComponents\Undraw\Components\Illustrations\UndrawSnowGlobeComponent::class => 'snow-globe',
            \BladeComponents\Undraw\Components\Illustrations\UndrawSnowmanComponent::class => 'snowman',
            \BladeComponents\Undraw\Components\Illustrations\UndrawSocialBioComponent::class => 'social-bio',
            \BladeComponents\Undraw\Components\Illustrations\UndrawSocialDashboardComponent::class => 'social-dashboard',
            \BladeComponents\Undraw\Components\Illustrations\UndrawSocialDistancingComponent::class => 'social-distancing',
            \BladeComponents\Undraw\Components\Illustrations\UndrawSocialExpertComponent::class => 'social-expert',
            \BladeComponents\Undraw\Components\Illustrations\UndrawSocialFriendsComponent::class => 'social-friends',
            \BladeComponents\Undraw\Components\Illustrations\UndrawSocialGirlComponent::class => 'social-girl',
            \BladeComponents\Undraw\Components\Illustrations\UndrawSocialGrowthComponent::class => 'social-growth',
            \BladeComponents\Undraw\Components\Illustrations\UndrawSocialIdeasComponent::class => 'social-ideas',
            \BladeComponents\Undraw\Components\Illustrations\UndrawSocialInfluencerComponent::class => 'social-influencer',
            \BladeComponents\Undraw\Components\Illustrations\UndrawSocialInteractionComponent::class => 'social-interaction',
            \BladeComponents\Undraw\Components\Illustrations\UndrawSocialLifeComponent::class => 'social-life',
            \BladeComponents\Undraw\Components\Illustrations\UndrawSocialMediaComponent::class => 'social-media',
            \BladeComponents\Undraw\Components\Illustrations\UndrawSocialNetworkingComponent::class => 'social-networking',
            \BladeComponents\Undraw\Components\Illustrations\UndrawSocialNotificationsComponent::class => 'social-notifications',
            \BladeComponents\Undraw\Components\Illustrations\UndrawSocialSerenityComponent::class => 'social-serenity',
            \BladeComponents\Undraw\Components\Illustrations\UndrawSocialShareComponent::class => 'social-share',
            \BladeComponents\Undraw\Components\Illustrations\UndrawSocialSharingComponent::class => 'social-sharing',
            \BladeComponents\Undraw\Components\Illustrations\UndrawSocialStrategyComponent::class => 'social-strategy',
            \BladeComponents\Undraw\Components\Illustrations\UndrawSocialThinkingComponent::class => 'social-thinking',
            \BladeComponents\Undraw\Components\Illustrations\UndrawSocialTreeComponent::class => 'social-tree',
            \BladeComponents\Undraw\Components\Illustrations\UndrawSocialUpdateComponent::class => 'social-update',
            \BladeComponents\Undraw\Components\Illustrations\UndrawSocialUserComponent::class => 'social-user',
            \BladeComponents\Undraw\Components\Illustrations\UndrawSoftwareEngineerComponent::class => 'software-engineer',
            \BladeComponents\Undraw\Components\Illustrations\UndrawSolutionMindsetComponent::class => 'solution-mindset',
            \BladeComponents\Undraw\Components\Illustrations\UndrawSortingThoughtsComponent::class => 'sorting-thoughts',
            \BladeComponents\Undraw\Components\Illustrations\UndrawSourceCodeComponent::class => 'source-code',
            \BladeComponents\Undraw\Components\Illustrations\UndrawSpecialEventComponent::class => 'special-event',
            \BladeComponents\Undraw\Components\Illustrations\UndrawSpecsComponent::class => 'specs',
            \BladeComponents\Undraw\Components\Illustrations\UndrawSpeechToTextComponent::class => 'speech-to-text',
            \BladeComponents\Undraw\Components\Illustrations\UndrawSpeedTestComponent::class => 'speed-test',
            \BladeComponents\Undraw\Components\Illustrations\UndrawSplitTestingComponent::class => 'split-testing',
            \BladeComponents\Undraw\Components\Illustrations\UndrawSpookySelfComponent::class => 'spooky-self',
            \BladeComponents\Undraw\Components\Illustrations\UndrawSpreadLoveComponent::class => 'spread-love',
            \BladeComponents\Undraw\Components\Illustrations\UndrawSpreadsheetComponent::class => 'spreadsheet',
            \BladeComponents\Undraw\Components\Illustrations\UndrawSpreadsheetsComponent::class => 'spreadsheets',
            \BladeComponents\Undraw\Components\Illustrations\UndrawStabilityBallComponent::class => 'stability-ball',
            \BladeComponents\Undraw\Components\Illustrations\UndrawStandOutComponent::class => 'stand-out',
            \BladeComponents\Undraw\Components\Illustrations\UndrawStarlinkComponent::class => 'starlink',
            \BladeComponents\Undraw\Components\Illustrations\UndrawStarryWindowComponent::class => 'starry-window',
            \BladeComponents\Undraw\Components\Illustrations\UndrawStarsComponent::class => 'stars',
            \BladeComponents\Undraw\Components\Illustrations\UndrawStartBuildingComponent::class => 'start-building',
            \BladeComponents\Undraw\Components\Illustrations\UndrawStartledComponent::class => 'startled',
            \BladeComponents\Undraw\Components\Illustrations\UndrawStartupLifeComponent::class => 'startup-life',
            \BladeComponents\Undraw\Components\Illustrations\UndrawStaticAssetsComponent::class => 'static-assets',
            \BladeComponents\Undraw\Components\Illustrations\UndrawStaticWebsiteComponent::class => 'static-website',
            \BladeComponents\Undraw\Components\Illustrations\UndrawStatisticChartComponent::class => 'statistic-chart',
            \BladeComponents\Undraw\Components\Illustrations\UndrawStatisticsComponent::class => 'statistics',
            \BladeComponents\Undraw\Components\Illustrations\UndrawStatusUpdateComponent::class => 'status-update',
            \BladeComponents\Undraw\Components\Illustrations\UndrawStayingInComponent::class => 'staying-in',
            \BladeComponents\Undraw\Components\Illustrations\UndrawStepToTheSunComponent::class => 'step-to-the-sun',
            \BladeComponents\Undraw\Components\Illustrations\UndrawSteppingUpComponent::class => 'stepping-up',
            \BladeComponents\Undraw\Components\Illustrations\UndrawStepsComponent::class => 'steps',
            \BladeComponents\Undraw\Components\Illustrations\UndrawStockPricesComponent::class => 'stock-prices',
            \BladeComponents\Undraw\Components\Illustrations\UndrawStrandedTravelerComponent::class => 'stranded-traveler',
            \BladeComponents\Undraw\Components\Illustrations\UndrawStreetFoodComponent::class => 'street-food',
            \BladeComponents\Undraw\Components\Illustrations\UndrawStripePaymentsComponent::class => 'stripe-payments',
            \BladeComponents\Undraw\Components\Illustrations\UndrawStudyingComponent::class => 'studying',
            \BladeComponents\Undraw\Components\Illustrations\UndrawSubscribeComponent::class => 'subscribe',
            \BladeComponents\Undraw\Components\Illustrations\UndrawSubscriberComponent::class => 'subscriber',
            \BladeComponents\Undraw\Components\Illustrations\UndrawSubscriptionsComponent::class => 'subscriptions',
            \BladeComponents\Undraw\Components\Illustrations\UndrawSuburbsComponent::class => 'suburbs',
            \BladeComponents\Undraw\Components\Illustrations\UndrawSubwayComponent::class => 'subway',
            \BladeComponents\Undraw\Components\Illustrations\UndrawSuccessFactorsComponent::class => 'success-factors',
            \BladeComponents\Undraw\Components\Illustrations\UndrawSuccessfulPurchaseComponent::class => 'successful-purchase',
            \BladeComponents\Undraw\Components\Illustrations\UndrawSummerComponent::class => 'summer',
            \BladeComponents\Undraw\Components\Illustrations\UndrawSunlightComponent::class => 'sunlight',
            \BladeComponents\Undraw\Components\Illustrations\UndrawSunnyDayComponent::class => 'sunny-day',
            \BladeComponents\Undraw\Components\Illustrations\UndrawSuperThankYouComponent::class => 'super-thank-you',
            \BladeComponents\Undraw\Components\Illustrations\UndrawSuperWomanComponent::class => 'super-woman',
            \BladeComponents\Undraw\Components\Illustrations\UndrawSuperheroComponent::class => 'superhero',
            \BladeComponents\Undraw\Components\Illustrations\UndrawSurferComponent::class => 'surfer',
            \BladeComponents\Undraw\Components\Illustrations\UndrawSurveillanceComponent::class => 'surveillance',
            \BladeComponents\Undraw\Components\Illustrations\UndrawSurveyComponent::class => 'survey',
            \BladeComponents\Undraw\Components\Illustrations\UndrawSweetHomeComponent::class => 'sweet-home',
            \BladeComponents\Undraw\Components\Illustrations\UndrawSwipeComponent::class => 'swipe',
            \BladeComponents\Undraw\Components\Illustrations\UndrawSwipeOptionsComponent::class => 'swipe-options',
            \BladeComponents\Undraw\Components\Illustrations\UndrawSwipeProfilesComponent::class => 'swipe-profiles',
            \BladeComponents\Undraw\Components\Illustrations\UndrawSwitchesComponent::class => 'switches',
            \BladeComponents\Undraw\Components\Illustrations\UndrawSyncComponent::class => 'sync',
            \BladeComponents\Undraw\Components\Illustrations\UndrawSyncFilesComponent::class => 'sync-files',
            \BladeComponents\Undraw\Components\Illustrations\UndrawSynchronizeComponent::class => 'synchronize',
            \BladeComponents\Undraw\Components\Illustrations\UndrawTabsComponent::class => 'tabs',
            \BladeComponents\Undraw\Components\Illustrations\UndrawTailwindCSSComponent::class => 'tailwind-css',
            \BladeComponents\Undraw\Components\Illustrations\UndrawTakeOutBoxesComponent::class => 'take-out-boxes',
            \BladeComponents\Undraw\Components\Illustrations\UndrawTakenComponent::class => 'taken',
            \BladeComponents\Undraw\Components\Illustrations\UndrawTakingNotesComponent::class => 'taking-notes',
            \BladeComponents\Undraw\Components\Illustrations\UndrawTakingSelfieComponent::class => 'taking-selfie',
            \BladeComponents\Undraw\Components\Illustrations\UndrawTargetComponent::class => 'target',
            \BladeComponents\Undraw\Components\Illustrations\UndrawTaskComponent::class => 'task',
            \BladeComponents\Undraw\Components\Illustrations\UndrawTaskListComponent::class => 'task-list',
            \BladeComponents\Undraw\Components\Illustrations\UndrawTasksComponent::class => 'tasks',
            \BladeComponents\Undraw\Components\Illustrations\UndrawTastingComponent::class => 'tasting',
            \BladeComponents\Undraw\Components\Illustrations\UndrawTeacherComponent::class => 'teacher',
            \BladeComponents\Undraw\Components\Illustrations\UndrawTeachingComponent::class => 'teaching',
            \BladeComponents\Undraw\Components\Illustrations\UndrawTeamChatComponent::class => 'team-chat',
            \BladeComponents\Undraw\Components\Illustrations\UndrawTeamCollaborationComponent::class => 'team-collaboration',
            \BladeComponents\Undraw\Components\Illustrations\UndrawTeamComponent::class => 'team',
            \BladeComponents\Undraw\Components\Illustrations\UndrawTeamGoalsComponent::class => 'team-goals',
            \BladeComponents\Undraw\Components\Illustrations\UndrawTeamPageComponent::class => 'team-page',
            \BladeComponents\Undraw\Components\Illustrations\UndrawTeamSpiritComponent::class => 'team-spirit',
            \BladeComponents\Undraw\Components\Illustrations\UndrawTeamUpComponent::class => 'team-up',
            \BladeComponents\Undraw\Components\Illustrations\UndrawTeamWorkComponent::class => 'team-work',
            \BladeComponents\Undraw\Components\Illustrations\UndrawTeamworkComponent::class => 'teamwork',
            \BladeComponents\Undraw\Components\Illustrations\UndrawTeddyBearComponent::class => 'teddy-bear',
            \BladeComponents\Undraw\Components\Illustrations\UndrawTermSheetComponent::class => 'term-sheet',
            \BladeComponents\Undraw\Components\Illustrations\UndrawTermsComponent::class => 'terms',
            \BladeComponents\Undraw\Components\Illustrations\UndrawTextFieldComponent::class => 'text-field',
            \BladeComponents\Undraw\Components\Illustrations\UndrawTextFilesComponent::class => 'text-files',
            \BladeComponents\Undraw\Components\Illustrations\UndrawTextingComponent::class => 'texting',
            \BladeComponents\Undraw\Components\Illustrations\UndrawTheSearchComponent::class => 'the-search',
            \BladeComponents\Undraw\Components\Illustrations\UndrawTheWorldIsMineComponent::class => 'the-world-is-mine',
            \BladeComponents\Undraw\Components\Illustrations\UndrawThingsToSayComponent::class => 'things-to-say',
            \BladeComponents\Undraw\Components\Illustrations\UndrawThoughtProcessComponent::class => 'thought-process',
            \BladeComponents\Undraw\Components\Illustrations\UndrawThoughtsComponent::class => 'thoughts',
            \BladeComponents\Undraw\Components\Illustrations\UndrawThroughTheDesertComponent::class => 'through-the-desert',
            \BladeComponents\Undraw\Components\Illustrations\UndrawThroughTheParkComponent::class => 'through-the-park',
            \BladeComponents\Undraw\Components\Illustrations\UndrawThroughTheWindowComponent::class => 'through-the-window',
            \BladeComponents\Undraw\Components\Illustrations\UndrawThrowAwayComponent::class => 'throw-away',
            \BladeComponents\Undraw\Components\Illustrations\UndrawThrowDownComponent::class => 'throw-down',
            \BladeComponents\Undraw\Components\Illustrations\UndrawTimeManagementComponent::class => 'time-management',
            \BladeComponents\Undraw\Components\Illustrations\UndrawTimelineComponent::class => 'timeline',
            \BladeComponents\Undraw\Components\Illustrations\UndrawToDoComponent::class => 'to-do',
            \BladeComponents\Undraw\Components\Illustrations\UndrawToDoListComponent::class => 'to-do-list',
            \BladeComponents\Undraw\Components\Illustrations\UndrawToTheMoonComponent::class => 'to-the-moon',
            \BladeComponents\Undraw\Components\Illustrations\UndrawToTheStarsComponent::class => 'to-the-stars',
            \BladeComponents\Undraw\Components\Illustrations\UndrawTogetherComponent::class => 'together',
            \BladeComponents\Undraw\Components\Illustrations\UndrawTouristMapComponent::class => 'tourist-map',
            \BladeComponents\Undraw\Components\Illustrations\UndrawTowingComponent::class => 'towing',
            \BladeComponents\Undraw\Components\Illustrations\UndrawTownComponent::class => 'town',
            \BladeComponents\Undraw\Components\Illustrations\UndrawToyCarComponent::class => 'toy-car',
            \BladeComponents\Undraw\Components\Illustrations\UndrawTrackAndFieldComponent::class => 'track-and-field',
            \BladeComponents\Undraw\Components\Illustrations\UndrawTransferFilesComponent::class => 'transfer-files',
            \BladeComponents\Undraw\Components\Illustrations\UndrawTransferMoneyComponent::class => 'transfer-money',
            \BladeComponents\Undraw\Components\Illustrations\UndrawTravelBookingComponent::class => 'travel-booking',
            \BladeComponents\Undraw\Components\Illustrations\UndrawTravelModeComponent::class => 'travel-mode',
            \BladeComponents\Undraw\Components\Illustrations\UndrawTravelPlansComponent::class => 'travel-plans',
            \BladeComponents\Undraw\Components\Illustrations\UndrawTravelTogetherComponent::class => 'travel-together',
            \BladeComponents\Undraw\Components\Illustrations\UndrawTravelersComponent::class => 'travelers',
            \BladeComponents\Undraw\Components\Illustrations\UndrawTravelingComponent::class => 'traveling',
            \BladeComponents\Undraw\Components\Illustrations\UndrawTreasureComponent::class => 'treasure',
            \BladeComponents\Undraw\Components\Illustrations\UndrawTreeSwingComponent::class => 'tree-swing',
            \BladeComponents\Undraw\Components\Illustrations\UndrawTrendsComponent::class => 'trends',
            \BladeComponents\Undraw\Components\Illustrations\UndrawTrendyInterfaceComponent::class => 'trendy-interface',
            \BladeComponents\Undraw\Components\Illustrations\UndrawTripComponent::class => 'trip',
            \BladeComponents\Undraw\Components\Illustrations\UndrawTrueFriendsComponent::class => 'true-friends',
            \BladeComponents\Undraw\Components\Illustrations\UndrawTrueLoveComponent::class => 'true-love',
            \BladeComponents\Undraw\Components\Illustrations\UndrawTutorialVideoComponent::class => 'tutorial-video',
            \BladeComponents\Undraw\Components\Illustrations\UndrawTweetstormComponent::class => 'tweetstorm',
            \BladeComponents\Undraw\Components\Illustrations\UndrawTwoFactorAuthenticationComponent::class => 'two-factor-authentication',
            \BladeComponents\Undraw\Components\Illustrations\UndrawTypewriterComponent::class => 'typewriter',
            \BladeComponents\Undraw\Components\Illustrations\UndrawTypingComponent::class => 'typing',
            \BladeComponents\Undraw\Components\Illustrations\UndrawUnDraw1000Component::class => 'undraw-1000',
            \BladeComponents\Undraw\Components\Illustrations\UndrawUnboxingComponent::class => 'unboxing',
            \BladeComponents\Undraw\Components\Illustrations\UndrawUnderConstructionComponent::class => 'under-construction',
            \BladeComponents\Undraw\Components\Illustrations\UndrawUnexpectedFriendsComponent::class => 'unexpected-friends',
            \BladeComponents\Undraw\Components\Illustrations\UndrawUnicornComponent::class => 'unicorn',
            \BladeComponents\Undraw\Components\Illustrations\UndrawUnlockComponent::class => 'unlock',
            \BladeComponents\Undraw\Components\Illustrations\UndrawUpToDateComponent::class => 'up-to-date',
            \BladeComponents\Undraw\Components\Illustrations\UndrawUpdateComponent::class => 'update',
            \BladeComponents\Undraw\Components\Illustrations\UndrawUpdatedComponent::class => 'updated',
            \BladeComponents\Undraw\Components\Illustrations\UndrawUpdatedResumeComponent::class => 'updated-resume',
            \BladeComponents\Undraw\Components\Illustrations\UndrawUpdatesComponent::class => 'updates',
            \BladeComponents\Undraw\Components\Illustrations\UndrawUpgradeComponent::class => 'upgrade',
            \BladeComponents\Undraw\Components\Illustrations\UndrawUploadComponent::class => 'upload',
            \BladeComponents\Undraw\Components\Illustrations\UndrawUploadImageComponent::class => 'upload-image',
            \BladeComponents\Undraw\Components\Illustrations\UndrawUploadingComponent::class => 'uploading',
            \BladeComponents\Undraw\Components\Illustrations\UndrawUpvoteComponent::class => 'upvote',
            \BladeComponents\Undraw\Components\Illustrations\UndrawUrbanDesignComponent::class => 'urban-design',
            \BladeComponents\Undraw\Components\Illustrations\UndrawUsabilityTestingComponent::class => 'usability-testing',
            \BladeComponents\Undraw\Components\Illustrations\UndrawUserFlowComponent::class => 'user-flow',
            \BladeComponents\Undraw\Components\Illustrations\UndrawVRChatComponent::class => 'vr-chat',
            \BladeComponents\Undraw\Components\Illustrations\UndrawVaultComponent::class => 'vault',
            \BladeComponents\Undraw\Components\Illustrations\UndrawVerifiedComponent::class => 'verified',
            \BladeComponents\Undraw\Components\Illustrations\UndrawVersionControlComponent::class => 'version-control',
            \BladeComponents\Undraw\Components\Illustrations\UndrawVideoCallComponent::class => 'video-call',
            \BladeComponents\Undraw\Components\Illustrations\UndrawVideoFilesComponent::class => 'video-files',
            \BladeComponents\Undraw\Components\Illustrations\UndrawVideoGameNightComponent::class => 'video-game-night',
            \BladeComponents\Undraw\Components\Illustrations\UndrawVideoInfluencerComponent::class => 'video-influencer',
            \BladeComponents\Undraw\Components\Illustrations\UndrawVideoStreamingComponent::class => 'video-streaming',
            \BladeComponents\Undraw\Components\Illustrations\UndrawVideoUploadComponent::class => 'video-upload',
            \BladeComponents\Undraw\Components\Illustrations\UndrawVideographerComponent::class => 'videographer',
            \BladeComponents\Undraw\Components\Illustrations\UndrawVirtualAssistantComponent::class => 'virtual-assistant',
            \BladeComponents\Undraw\Components\Illustrations\UndrawVirtualRealityComponent::class => 'virtual-reality',
            \BladeComponents\Undraw\Components\Illustrations\UndrawVisionaryTechnologyComponent::class => 'visionary-technology',
            \BladeComponents\Undraw\Components\Illustrations\UndrawVisualDataComponent::class => 'visual-data',
            \BladeComponents\Undraw\Components\Illustrations\UndrawVisualizationComponent::class => 'visualization',
            \BladeComponents\Undraw\Components\Illustrations\UndrawVoiceAssistantComponent::class => 'voice-assistant',
            \BladeComponents\Undraw\Components\Illustrations\UndrawVoiceControlComponent::class => 'voice-control',
            \BladeComponents\Undraw\Components\Illustrations\UndrawVoiceInterfaceComponent::class => 'voice-interface',
            \BladeComponents\Undraw\Components\Illustrations\UndrawVoidComponent::class => 'void',
            \BladeComponents\Undraw\Components\Illustrations\UndrawVotingComponent::class => 'voting',
            \BladeComponents\Undraw\Components\Illustrations\UndrawWaitInLineComponent::class => 'wait-in-line',
            \BladeComponents\Undraw\Components\Illustrations\UndrawWaitingForYouComponent::class => 'waiting-for-you',
            \BladeComponents\Undraw\Components\Illustrations\UndrawWalkDreamingComponent::class => 'walk-dreaming',
            \BladeComponents\Undraw\Components\Illustrations\UndrawWalkInTheCityComponent::class => 'walk-in-the-city',
            \BladeComponents\Undraw\Components\Illustrations\UndrawWalkingAroundComponent::class => 'walking-around',
            \BladeComponents\Undraw\Components\Illustrations\UndrawWalkingInRainComponent::class => 'walking-in-rain',
            \BladeComponents\Undraw\Components\Illustrations\UndrawWalkingOutsideComponent::class => 'walking-outside',
            \BladeComponents\Undraw\Components\Illustrations\UndrawWalkingTogetherComponent::class => 'walking-together',
            \BladeComponents\Undraw\Components\Illustrations\UndrawWallPostComponent::class => 'wall-post',
            \BladeComponents\Undraw\Components\Illustrations\UndrawWalletComponent::class => 'wallet',
            \BladeComponents\Undraw\Components\Illustrations\UndrawWanderingMindComponent::class => 'wandering-mind',
            \BladeComponents\Undraw\Components\Illustrations\UndrawWarningComponent::class => 'warning',
            \BladeComponents\Undraw\Components\Illustrations\UndrawWashHandsComponent::class => 'wash-hands',
            \BladeComponents\Undraw\Components\Illustrations\UndrawWatchApplicationComponent::class => 'watch-application',
            \BladeComponents\Undraw\Components\Illustrations\UndrawWeatherAppComponent::class => 'weather-app',
            \BladeComponents\Undraw\Components\Illustrations\UndrawWeatherComponent::class => 'weather',
            \BladeComponents\Undraw\Components\Illustrations\UndrawWeatherNotificationComponent::class => 'weather-notification',
            \BladeComponents\Undraw\Components\Illustrations\UndrawWebBrowsingComponent::class => 'web-browsing',
            \BladeComponents\Undraw\Components\Illustrations\UndrawWebDeveloperComponent::class => 'web-developer',
            \BladeComponents\Undraw\Components\Illustrations\UndrawWebDevelopmentComponent::class => 'web-development',
            \BladeComponents\Undraw\Components\Illustrations\UndrawWebDevicesComponent::class => 'web-devices',
            \BladeComponents\Undraw\Components\Illustrations\UndrawWebSearchComponent::class => 'web-search',
            \BladeComponents\Undraw\Components\Illustrations\UndrawWebShoppingComponent::class => 'web-shopping',
            \BladeComponents\Undraw\Components\Illustrations\UndrawWebsiteBuilderComponent::class => 'website-builder',
            \BladeComponents\Undraw\Components\Illustrations\UndrawWebsiteSetupComponent::class => 'website-setup',
            \BladeComponents\Undraw\Components\Illustrations\UndrawWeddingComponent::class => 'wedding',
            \BladeComponents\Undraw\Components\Illustrations\UndrawWelcomeCatsComponent::class => 'welcome-cats',
            \BladeComponents\Undraw\Components\Illustrations\UndrawWelcomeComponent::class => 'welcome',
            \BladeComponents\Undraw\Components\Illustrations\UndrawWelcomingComponent::class => 'welcoming',
            \BladeComponents\Undraw\Components\Illustrations\UndrawWellDoneComponent::class => 'well-done',
            \BladeComponents\Undraw\Components\Illustrations\UndrawWildernessComponent::class => 'wilderness',
            \BladeComponents\Undraw\Components\Illustrations\UndrawWindTurbineComponent::class => 'wind-turbine',
            \BladeComponents\Undraw\Components\Illustrations\UndrawWindowShoppingComponent::class => 'window-shopping',
            \BladeComponents\Undraw\Components\Illustrations\UndrawWindowsComponent::class => 'windows',
            \BladeComponents\Undraw\Components\Illustrations\UndrawWindyDayComponent::class => 'windy-day',
            \BladeComponents\Undraw\Components\Illustrations\UndrawWineTastingComponent::class => 'wine-tasting',
            \BladeComponents\Undraw\Components\Illustrations\UndrawWinnersComponent::class => 'winners',
            \BladeComponents\Undraw\Components\Illustrations\UndrawWinterActivitiesComponent::class => 'winter-activities',
            \BladeComponents\Undraw\Components\Illustrations\UndrawWinterDesignerComponent::class => 'winter-designer',
            \BladeComponents\Undraw\Components\Illustrations\UndrawWinterMagicComponent::class => 'winter-magic',
            \BladeComponents\Undraw\Components\Illustrations\UndrawWinterRoadComponent::class => 'winter-road',
            \BladeComponents\Undraw\Components\Illustrations\UndrawWinterSkatingComponent::class => 'winter-skating',
            \BladeComponents\Undraw\Components\Illustrations\UndrawWinterWalkComponent::class => 'winter-walk',
            \BladeComponents\Undraw\Components\Illustrations\UndrawWireframingComponent::class => 'wireframing',
            \BladeComponents\Undraw\Components\Illustrations\UndrawWishesComponent::class => 'wishes',
            \BladeComponents\Undraw\Components\Illustrations\UndrawWishlistComponent::class => 'wishlist',
            \BladeComponents\Undraw\Components\Illustrations\UndrawWithLoveComponent::class => 'with-love',
            \BladeComponents\Undraw\Components\Illustrations\UndrawWomanComponent::class => 'woman',
            \BladeComponents\Undraw\Components\Illustrations\UndrawWomenDayComponent::class => 'women-day',
            \BladeComponents\Undraw\Components\Illustrations\UndrawWordOfMouthComponent::class => 'word-of-mouth',
            \BladeComponents\Undraw\Components\Illustrations\UndrawWordpressComponent::class => 'wordpress',
            \BladeComponents\Undraw\Components\Illustrations\UndrawWorkChatComponent::class => 'work-chat',
            \BladeComponents\Undraw\Components\Illustrations\UndrawWorkFromAnywhereComponent::class => 'work-from-anywhere',
            \BladeComponents\Undraw\Components\Illustrations\UndrawWorkInProgressComponent::class => 'work-in-progress',
            \BladeComponents\Undraw\Components\Illustrations\UndrawWorkTimeComponent::class => 'work-time',
            \BladeComponents\Undraw\Components\Illustrations\UndrawWorkTogetherComponent::class => 'work-together',
            \BladeComponents\Undraw\Components\Illustrations\UndrawWorkingComponent::class => 'working',
            \BladeComponents\Undraw\Components\Illustrations\UndrawWorkingFromAnywhereComponent::class => 'working-from-anywhere',
            \BladeComponents\Undraw\Components\Illustrations\UndrawWorkingLateComponent::class => 'working-late',
            \BladeComponents\Undraw\Components\Illustrations\UndrawWorkingOutComponent::class => 'working-out',
            \BladeComponents\Undraw\Components\Illustrations\UndrawWorkingRemotelyComponent::class => 'working-remotely',
            \BladeComponents\Undraw\Components\Illustrations\UndrawWorkoutComponent::class => 'workout',
            \BladeComponents\Undraw\Components\Illustrations\UndrawWorldComponent::class => 'world',
            \BladeComponents\Undraw\Components\Illustrations\UndrawWriterComponent::class => 'writer',
            \BladeComponents\Undraw\Components\Illustrations\UndrawXmasSnowmanComponent::class => 'xmas-snowman',
            \BladeComponents\Undraw\Components\Illustrations\UndrawXmasSurpriseComponent::class => 'xmas-surprise',
            \BladeComponents\Undraw\Components\Illustrations\UndrawYachtComponent::class => 'yacht',
            \BladeComponents\Undraw\Components\Illustrations\UndrawYear2022Component::class => 'year-2022',
            \BladeComponents\Undraw\Components\Illustrations\UndrawYogaComponent::class => 'yoga',
            \BladeComponents\Undraw\Components\Illustrations\UndrawYoungAndHappyComponent::class => 'young-and-happy',
            \BladeComponents\Undraw\Components\Illustrations\UndrawYoutubeTutorialComponent::class => 'youtube-tutorial',
            \BladeComponents\Undraw\Components\Illustrations\UndrawZoomInComponent::class => 'zoom-in',
        ]);
    }
}
